@@ -22,7 +22,6 @@ use crate::cli_util::CommandHelper;
 use crate::command_error::CommandError;
 use crate::complete;
 use crate::config::resolved_config_values;
-use crate::config::to_toml_value;
 use crate::config::AnnotatedValue;
 use crate::generic_templater::GenericTemplateLanguage;
 use crate::template_builder::TemplateLanguage as _;
@@ -53,7 +52,7 @@ pub struct ConfigListArgs {
     /// * `value: String`: Serialized value in TOML syntax.
     /// * `overridden: Boolean`: True if the value is shadowed by other.
     ///
-    /// For the syntax, see https://martinvonz.github.io/jj/latest/templates/
+    /// For the syntax, see https://jj-vcs.github.io/jj/latest/templates/
     #[arg(long, short = 'T', verbatim_doc_comment)]
     template: Option<String>,
 }
@@ -75,32 +74,27 @@ pub fn cmd_config_list(
             .labeled("config_list")
     };
 
-    ui.request_pager();
-    let mut formatter = ui.stdout_formatter();
     let name_path = args.name.clone().unwrap_or_else(ConfigNamePathBuf::root);
-    let mut wrote_values = false;
-    for annotated in resolved_config_values(command.settings().config(), &name_path) {
-        // Remove overridden values.
-        if annotated.is_overridden && !args.include_overridden {
-            continue;
-        }
-
-        if let Some(target_source) = args.level.get_source_kind() {
-            if target_source != annotated.source {
-                continue;
-            }
-        }
-
-        // Skip built-ins if not included.
-        if !args.include_defaults && annotated.source == ConfigSource::Default {
-            continue;
-        }
-
-        template.format(&annotated, formatter.as_mut())?;
-        wrote_values = true;
+    let mut annotated_values = resolved_config_values(command.settings().config(), &name_path);
+    // The default layer could be excluded beforehand as layers[len..], but we
+    // can't do the same for "annotated.source == target_source" in order for
+    // resolved_config_values() to mark values overridden by the upper layers.
+    if let Some(target_source) = args.level.get_source_kind() {
+        annotated_values.retain(|annotated| annotated.source == target_source);
+    } else if !args.include_defaults {
+        annotated_values.retain(|annotated| annotated.source != ConfigSource::Default);
     }
-    drop(formatter);
-    if !wrote_values {
+    if !args.include_overridden {
+        annotated_values.retain(|annotated| !annotated.is_overridden);
+    }
+
+    if !annotated_values.is_empty() {
+        ui.request_pager();
+        let mut formatter = ui.stdout_formatter();
+        for annotated in &annotated_values {
+            template.format(annotated, formatter.as_mut())?;
+        }
+    } else {
         // Note to stderr explaining why output is empty.
         if let Some(name) = &args.name {
             writeln!(ui.warning_default(), "No matching config key for {name}")?;
@@ -122,8 +116,9 @@ fn config_template_language() -> GenericTemplateLanguage<'static, AnnotatedValue
     });
     language.add_keyword("value", |self_property| {
         // TODO: would be nice if we can provide raw dynamically-typed value
+        // .decorated("", "") to trim leading/trailing whitespace
         let out_property =
-            self_property.and_then(|annotated| Ok(to_toml_value(&annotated.value)?.to_string()));
+            self_property.map(|annotated| annotated.value.decorated("", "").to_string());
         Ok(L::wrap_string(out_property))
     });
     language.add_keyword("overridden", |self_property| {
