@@ -43,12 +43,14 @@ use crate::ui::Ui;
 #[derive(clap::Args, Clone, Debug)]
 #[command(visible_aliases = &["desc"])]
 pub(crate) struct DescribeArgs {
-    /// The revision(s) whose description to edit
-    #[arg(default_value = "@", add = ArgValueCandidates::new(complete::mutable_revisions))]
-    revisions: Vec<RevisionArg>,
-    /// Ignored (but lets you pass `-r` for consistency with other commands)
-    #[arg(short = 'r', hide = true, action = clap::ArgAction::Count)]
-    unused_revision: u8,
+    /// The revision(s) whose description to edit (default: @)
+    #[arg(
+        value_name = "REVSETS",
+        add = ArgValueCandidates::new(complete::mutable_revisions)
+    )]
+    revisions_pos: Vec<RevisionArg>,
+    #[arg(short = 'r', hide = true, value_name = "REVSETS")]
+    revisions_opt: Vec<RevisionArg>,
     /// The change description to use (don't open editor)
     ///
     /// If multiple revisions are specified, the same description will be used
@@ -95,10 +97,14 @@ pub(crate) fn cmd_describe(
     args: &DescribeArgs,
 ) -> Result<(), CommandError> {
     let mut workspace_command = command.workspace_helper(ui)?;
-    let commits: Vec<_> = workspace_command
-        .parse_union_revsets(ui, &args.revisions)?
-        .evaluate_to_commits()?
-        .try_collect()?; // in reverse topological order
+    let commits: Vec<_> = if !args.revisions_pos.is_empty() || !args.revisions_opt.is_empty() {
+        workspace_command
+            .parse_union_revsets(ui, &[&*args.revisions_pos, &*args.revisions_opt].concat())?
+    } else {
+        workspace_command.parse_revset(ui, &RevisionArg::AT)?
+    }
+    .evaluate_to_commits()?
+    .try_collect()?; // in reverse topological order
     if commits.is_empty() {
         writeln!(ui.status(), "No revisions to describe.")?;
         return Ok(());
@@ -142,12 +148,10 @@ pub(crate) fn cmd_describe(
             // Edit descriptions in topological order
             .rev()
             .map(|commit| -> Result<_, CommandError> {
-                let mut commit_builder = tx
-                    .repo_mut()
-                    .rewrite_commit(command.settings(), commit)
-                    .detach();
+                let mut commit_builder = tx.repo_mut().rewrite_commit(commit).detach();
                 if commit_builder.description().is_empty() {
-                    commit_builder.set_description(command.settings().default_description());
+                    commit_builder
+                        .set_description(command.settings().get_string("ui.default-description")?);
                 }
                 if args.reset_author {
                     let new_author = commit_builder.committer().clone();
@@ -237,14 +241,13 @@ pub(crate) fn cmd_describe(
     // rewriting the same commit multiple times, and adding additional entries
     // in the predecessor chain.
     tx.repo_mut().transform_descendants(
-        command.settings(),
         commit_descriptions
             .keys()
             .map(|&id| id.clone())
             .collect_vec(),
         |rewriter| {
             let old_commit_id = rewriter.old_commit().id().clone();
-            let mut commit_builder = rewriter.rebase(command.settings())?;
+            let mut commit_builder = rewriter.rebase()?;
             if let Some(description) = commit_descriptions.get(&old_commit_id) {
                 commit_builder = commit_builder.set_description(description);
                 if args.reset_author {
