@@ -36,7 +36,7 @@ pub fn cmd_git_import(
     // In non-colocated repo, Git HEAD will never be moved internally by jj.
     // That's why cmd_git_export() doesn't export the HEAD ref.
     git::import_head(tx.repo_mut())?;
-    let stats = git::import_refs(tx.repo_mut(), &command.settings().git_settings())?;
+    let stats = git::import_refs(tx.repo_mut(), &command.settings().git_settings()?)?;
     print_git_import_stats(ui, tx.repo(), &stats, true)?;
     tx.finish(ui, "import git refs")?;
     Ok(())
