@@ -21,7 +21,11 @@ pub mod push;
 pub mod remote;
 pub mod submodule;
 
+use std::path::Path;
+
 use clap::Subcommand;
+use jj_lib::config::ConfigFile;
+use jj_lib::config::ConfigSource;
 
 use self::clone::cmd_git_clone;
 use self::clone::GitCloneArgs;
@@ -48,7 +52,7 @@ use crate::ui::Ui;
 /// Commands for working with Git remotes and the underlying Git repo
 ///
 /// For a comparison with Git, including a table of commands, see
-/// https://martinvonz.github.io/jj/latest/git-comparison/.
+/// https://jj-vcs.github.io/jj/latest/git-comparison/.
 #[derive(Subcommand, Clone, Debug)]
 pub enum GitCommand {
     Clone(GitCloneArgs),
@@ -102,3 +106,21 @@ fn get_single_remote(git_repo: &git2::Repository) -> Result<Option<String>, Comm
         _ => None,
     })
 }
+
+/// Sets repository level `trunk()` alias to the specified remote branch.
+fn write_repository_level_trunk_alias(
+    ui: &Ui,
+    repo_path: &Path,
+    remote: &str,
+    branch: &str,
+) -> Result<(), CommandError> {
+    let mut file = ConfigFile::load_or_empty(ConfigSource::Repo, repo_path.join("config.toml"))?;
+    file.set_value(["revset-aliases", "trunk()"], format!("{branch}@{remote}"))
+        .expect("initial repo config shouldn't have invalid values");
+    file.save()?;
+    writeln!(
+        ui.status(),
+        r#"Setting the revset alias "trunk()" to "{branch}@{remote}""#,
+    )?;
+    Ok(())
+}
