@@ -13,17 +13,18 @@
 // limitations under the License.
 
 use clap_complete::ArgValueCandidates;
+use clap_complete::ArgValueCompleter;
 use jj_lib::backend::CommitId;
-use jj_lib::config::ConfigError;
+use jj_lib::config::ConfigGetError;
+use jj_lib::config::ConfigGetResultExt as _;
+use jj_lib::graph::reverse_graph;
 use jj_lib::graph::GraphEdgeType;
-use jj_lib::graph::ReverseGraphIterator;
 use jj_lib::graph::TopoGroupedGraphIterator;
 use jj_lib::repo::Repo;
 use jj_lib::revset::RevsetEvaluationError;
 use jj_lib::revset::RevsetExpression;
 use jj_lib::revset::RevsetFilterPredicate;
 use jj_lib::revset::RevsetIteratorExt;
-use jj_lib::settings::ConfigResultExt as _;
 use jj_lib::settings::UserSettings;
 use tracing::instrument;
 
@@ -46,26 +47,35 @@ use crate::ui::Ui;
 /// before parents. By default, the output only includes mutable revisions,
 /// along with some additional revisions for context. Use `jj log -r ::` to see
 /// all revisions. See `jj help -k revsets` (or
-/// https://martinvonz.github.io/jj/latest/revsets/) for information about the
+/// https://jj-vcs.github.io/jj/latest/revsets/) for information about the
 /// syntax.
 ///
 /// Spans of revisions that are not included in the graph per `--revisions` are
 /// rendered as a synthetic node labeled "(elided revisions)".
 ///
 /// The working-copy commit is indicated by a `@` symbol in the graph. Immutable
-/// revisions (https://martinvonz.github.io/jj/latest/config/#set-of-immutable-commits)
+/// revisions (https://jj-vcs.github.io/jj/latest/config/#set-of-immutable-commits)
 /// have a `◆` symbol. Other commits have a `○` symbol. To customize these
-/// symbols, see https://martinvonz.github.io/jj/latest/config/#node-style.
+/// symbols, see https://jj-vcs.github.io/jj/latest/config/#node-style.
 #[derive(clap::Args, Clone, Debug)]
 pub(crate) struct LogArgs {
     /// Which revisions to show
     ///
     /// If no paths nor revisions are specified, this defaults to the
     /// `revsets.log` setting.
-    #[arg(long, short, add = ArgValueCandidates::new(complete::all_revisions))]
+    #[arg(
+        long,
+        short,
+        value_name = "REVSETS",
+        add = ArgValueCandidates::new(complete::all_revisions)
+    )]
     revisions: Vec<RevisionArg>,
     /// Show revisions modifying the given paths
-    #[arg(value_hint = clap::ValueHint::AnyPath)]
+    #[arg(
+        value_name = "FILESETS",
+        value_hint = clap::ValueHint::AnyPath,
+        add = ArgValueCompleter::new(complete::log_files),
+    )]
     paths: Vec<String>,
     /// Show revisions in the opposite order (older revisions first)
     #[arg(long)]
@@ -91,7 +101,7 @@ pub(crate) struct LogArgs {
     /// Run `jj log -T` to list the built-in templates.
     ///
     /// You can also specify arbitrary template expressions. For the syntax,
-    /// see https://martinvonz.github.io/jj/latest/templates/.
+    /// see https://jj-vcs.github.io/jj/latest/templates/.
     ///
     /// If not specified, this defaults to the `templates.log` setting.
     #[arg(long, short = 'T')]
@@ -115,8 +125,8 @@ pub(crate) fn cmd_log(
     let revset_expression = {
         // only use default revset if neither revset nor path are specified
         let mut expression = if args.revisions.is_empty() && args.paths.is_empty() {
-            workspace_command
-                .parse_revset(ui, &RevisionArg::from(command.settings().default_revset()))?
+            let revset_string = command.settings().get_string("revsets.log")?;
+            workspace_command.parse_revset(ui, &RevisionArg::from(revset_string))?
         } else if !args.revisions.is_empty() {
             workspace_command.parse_union_revsets(ui, &args.revisions)?
         } else {
@@ -198,7 +208,7 @@ pub(crate) fn cmd_log(
                     }
                 }
                 if args.reversed {
-                    Box::new(ReverseGraphIterator::new(forward_iter)?)
+                    Box::new(reverse_graph(forward_iter)?.into_iter().map(Ok))
                 } else {
                     Box::new(forward_iter)
                 }
@@ -331,7 +341,7 @@ pub(crate) fn cmd_log(
 pub fn get_node_template(
     style: GraphStyle,
     settings: &UserSettings,
-) -> Result<String, ConfigError> {
+) -> Result<String, ConfigGetError> {
     let symbol = settings.get_string("templates.log_node").optional()?;
     let default = if style.is_ascii() {
         "builtin_log_node_ascii"
