@@ -32,12 +32,12 @@ use crate::ui::Ui;
 ///
 ///  * The working copy commit and its (first) parent, and a summary of the
 ///    changes between them
-///  * Conflicted bookmarks (see https://martinvonz.github.io/jj/latest/bookmarks/)
+///  * Conflicted bookmarks (see https://jj-vcs.github.io/jj/latest/bookmarks/)
 #[derive(clap::Args, Clone, Debug)]
 #[command(visible_alias = "st")]
 pub(crate) struct StatusArgs {
     /// Restrict the status display to these paths
-    #[arg(value_hint = clap::ValueHint::AnyPath)]
+    #[arg(value_name = "FILESETS", value_hint = clap::ValueHint::AnyPath)]
     paths: Vec<String>,
 }
 
