@@ -68,7 +68,7 @@ pub struct WorkspaceAddArgs {
     /// the new working-copy commit will be created with all these revisions as
     /// parents, i.e. the working-copy commit will exist as if you had run `jj
     /// new r1 r2 r3 ...`.
-    #[arg(long, short)]
+    #[arg(long, short, value_name = "REVSETS")]
     revision: Vec<RevisionArg>,
     /// How to handle sparse patterns when creating a new workspace.
     #[arg(long, value_enum, default_value_t = SparseInheritance::Copy)]
@@ -109,7 +109,6 @@ pub fn cmd_workspace_add(
     let working_copy_factory = command.get_working_copy_factory()?;
     let repo_path = old_workspace_command.repo_path();
     let (new_workspace, repo) = Workspace::init_workspace_with_existing_repo(
-        command.settings(),
         &destination_path,
         repo_path,
         repo,
@@ -185,10 +184,7 @@ pub fn cmd_workspace_add(
 
     let tree = merge_commit_trees(tx.repo(), &parents)?;
     let parent_ids = parents.iter().ids().cloned().collect_vec();
-    let new_wc_commit = tx
-        .repo_mut()
-        .new_commit(command.settings(), parent_ids, tree.id())
-        .write()?;
+    let new_wc_commit = tx.repo_mut().new_commit(parent_ids, tree.id()).write()?;
 
     tx.edit(&new_wc_commit)?;
     tx.finish(
