@@ -12,8 +12,10 @@ use jj_lib::backend::FileId;
 use jj_lib::backend::MergedTreeId;
 use jj_lib::backend::TreeValue;
 use jj_lib::conflicts;
-use jj_lib::conflicts::materialize_merge_result_to_bytes;
+use jj_lib::conflicts::choose_materialized_conflict_marker_len;
+use jj_lib::conflicts::materialize_merge_result_to_bytes_with_marker_len;
 use jj_lib::conflicts::ConflictMarkerStyle;
+use jj_lib::conflicts::MIN_CONFLICT_MARKER_LEN;
 use jj_lib::gitignore::GitIgnoreFile;
 use jj_lib::matchers::Matcher;
 use jj_lib::merge::Merge;
@@ -181,8 +183,23 @@ pub fn run_mergetool_external(
         .conflict_marker_style
         .unwrap_or(default_conflict_marker_style);
 
+    let uses_marker_length = find_all_variables(&editor.merge_args).contains(&"marker_length");
+
+    // If the merge tool doesn't get conflict markers pre-populated in the output
+    // file and doesn't accept "$marker_length", then we should default to accepting
+    // MIN_CONFLICT_MARKER_LEN since the merge tool can't know about our rules for
+    // conflict marker length.
+    let conflict_marker_len = if editor.merge_tool_edits_conflict_markers || uses_marker_length {
+        choose_materialized_conflict_marker_len(&content)
+    } else {
+        MIN_CONFLICT_MARKER_LEN
+    };
     let initial_output_content = if editor.merge_tool_edits_conflict_markers {
-        materialize_merge_result_to_bytes(&content, conflict_marker_style)
+        materialize_merge_result_to_bytes_with_marker_len(
+            &content,
+            conflict_marker_style,
+            conflict_marker_len,
+        )
     } else {
         BString::default()
     };
@@ -205,7 +222,7 @@ pub fn run_mergetool_external(
         // resolving the root path ever makes sense.
         "".to_owned()
     };
-    let paths: HashMap<&str, _> = files
+    let mut variables: HashMap<&str, _> = files
         .iter()
         .map(|(role, contents)| -> Result<_, ConflictResolveError> {
             let path = temp_dir.path().join(format!("{role}{suffix}"));
@@ -222,9 +239,10 @@ pub fn run_mergetool_external(
             ))
         })
         .try_collect()?;
+    variables.insert("marker_length", conflict_marker_len.to_string());
 
     let mut cmd = Command::new(&editor.program);
-    cmd.args(interpolate_variables(&editor.merge_args, &paths));
+    cmd.args(interpolate_variables(&editor.merge_args, &variables));
     tracing::info!(?cmd, "Invoking the external merge tool:");
     let exit_status = cmd
         .status()
@@ -245,7 +263,7 @@ pub fn run_mergetool_external(
     }
 
     let output_file_contents: Vec<u8> =
-        std::fs::read(paths.get("output").unwrap()).map_err(ExternalToolError::Io)?;
+        std::fs::read(variables.get("output").unwrap()).map_err(ExternalToolError::Io)?;
     if output_file_contents.is_empty() || output_file_contents == initial_output_content {
         return Err(ConflictResolveError::EmptyOrUnchanged);
     }
@@ -257,6 +275,7 @@ pub fn run_mergetool_external(
             repo_path,
             output_file_contents.as_slice(),
             conflict_marker_style,
+            conflict_marker_len,
         )
         .block_on()?
     } else {
@@ -280,7 +299,12 @@ pub fn run_mergetool_external(
     let new_tree_value = match new_file_ids.into_resolved() {
         Ok(new_file_id) => Merge::normal(TreeValue::File {
             id: new_file_id.unwrap(),
-            executable: false,
+            executable: conflict
+                .to_executable_merge()
+                .as_ref()
+                .and_then(Merge::resolve_trivial)
+                .copied()
+                .unwrap_or_default(),
         }),
         Err(new_file_ids) => conflict.with_new_file_ids(&new_file_ids),
     };
