@@ -31,17 +31,20 @@ fn test_absorb_simple() {
     test_env.jj_cmd_ok(&repo_path, &["new", "-m2"]);
     std::fs::write(repo_path.join("file1"), "1a\n1b\n2a\n2b\n").unwrap();
 
-    // Insert first and last lines
+    // Empty commit
     test_env.jj_cmd_ok(&repo_path, &["new"]);
+    let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb"]);
+    insta::assert_snapshot!(stderr, @"Nothing changed.");
+
+    // Insert first and last lines
     std::fs::write(repo_path.join("file1"), "1X\n1a\n1b\n2a\n2b\n2Z\n").unwrap();
     let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb"]);
     insta::assert_snapshot!(stderr, @r"
     Absorbed changes into these revisions:
-      zsuskuln 3c319ca8 2
-      kkmpptxz 6b722c47 1
-    Rebased 1 descendant commits.
-    Working copy now at: mzvwutvl dfb52c7a (empty) (no description set)
-    Parent commit      : zsuskuln 3c319ca8 2
+      zsuskuln 3027ca7a 2
+      kkmpptxz d0f1e8dd 1
+    Working copy now at: yqosqzyt 277bed24 (empty) (no description set)
+    Parent commit      : zsuskuln 3027ca7a 2
     ");
 
     // Modify middle line in hunk
@@ -49,10 +52,10 @@ fn test_absorb_simple() {
     let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb"]);
     insta::assert_snapshot!(stderr, @r"
     Absorbed changes into these revisions:
-      kkmpptxz 1027ba02 1
-    Rebased 2 descendant commits.
-    Working copy now at: mzvwutvl 7e01bf33 (empty) (no description set)
-    Parent commit      : zsuskuln 669278a7 2
+      kkmpptxz d366d92c 1
+    Rebased 1 descendant commits.
+    Working copy now at: vruxwmqv 32eb72fe (empty) (no description set)
+    Parent commit      : zsuskuln 5bf0bc06 2
     ");
 
     // Remove middle line from hunk
@@ -60,10 +63,9 @@ fn test_absorb_simple() {
     let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb"]);
     insta::assert_snapshot!(stderr, @r"
     Absorbed changes into these revisions:
-      zsuskuln 660c7cac 2
-    Rebased 1 descendant commits.
-    Working copy now at: mzvwutvl 39c8fe11 (empty) (no description set)
-    Parent commit      : zsuskuln 660c7cac 2
+      zsuskuln 6e2c4777 2
+    Working copy now at: yostqsxw 4a48490c (empty) (no description set)
+    Parent commit      : zsuskuln 6e2c4777 2
     ");
 
     // Insert ambiguous line in between
@@ -72,7 +74,7 @@ fn test_absorb_simple() {
     insta::assert_snapshot!(stderr, @"Nothing changed.");
 
     insta::assert_snapshot!(get_diffs(&test_env, &repo_path, "mutable()"), @r"
-    @  mzvwutvl a0e56cbc (no description set)
+    @  yostqsxw 80965bcc (no description set)
     │  diff --git a/file1 b/file1
     │  index 8653ca354d..88eb438902 100644
     │  --- a/file1
@@ -84,7 +86,7 @@ fn test_absorb_simple() {
     │  +Y
     │   2a
     │   2Z
-    ○  zsuskuln 660c7cac 2
+    ○  zsuskuln 6e2c4777 2
     │  diff --git a/file1 b/file1
     │  index ed237b5112..8653ca354d 100644
     │  --- a/file1
@@ -95,12 +97,12 @@ fn test_absorb_simple() {
     │   1b
     │  +2a
     │  +2Z
-    ○  kkmpptxz 1027ba02 1
+    ○  kkmpptxz d366d92c 1
     │  diff --git a/file1 b/file1
     │  index e69de29bb2..ed237b5112 100644
     │  --- a/file1
     │  +++ b/file1
-    │  @@ -1,0 +1,3 @@
+    │  @@ -0,0 +1,3 @@
     │  +1X
     │  +1A
     │  +1b
@@ -110,28 +112,26 @@ fn test_absorb_simple() {
        index 0000000000..e69de29bb2
     ");
     insta::assert_snapshot!(get_evolog(&test_env, &repo_path, "description(1)"), @r"
-    ○    kkmpptxz 1027ba02 1
+    ○    kkmpptxz d366d92c 1
     ├─╮
-    │ ○  mzvwutvl hidden 4624004f (no description set)
-    │ ○  mzvwutvl hidden dfb52c7a (empty) (no description set)
-    ○ │  kkmpptxz hidden 6b722c47 1
+    │ ○  yqosqzyt hidden c506fbc7 (no description set)
+    │ ○  yqosqzyt hidden 277bed24 (empty) (no description set)
+    ○    kkmpptxz hidden d0f1e8dd 1
     ├─╮
-    │ ○  mzvwutvl hidden 2342dbe2 (no description set)
+    │ ○  mzvwutvl hidden 8935ee61 (no description set)
     │ ○  mzvwutvl hidden 2bc3d2ce (empty) (no description set)
     ○  kkmpptxz hidden ee76d790 1
     ○  kkmpptxz hidden 677e62d5 (empty) 1
     ");
     insta::assert_snapshot!(get_evolog(&test_env, &repo_path, "description(2)"), @r"
-    ○    zsuskuln 660c7cac 2
+    ○    zsuskuln 6e2c4777 2
     ├─╮
-    │ ○  mzvwutvl hidden cb78f902 (no description set)
-    │ ○  mzvwutvl hidden 7e01bf33 (empty) (no description set)
-    │ ○  mzvwutvl hidden 4624004f (no description set)
-    │ ○  mzvwutvl hidden dfb52c7a (empty) (no description set)
-    ○ │  zsuskuln hidden 669278a7 2
-    ○ │  zsuskuln hidden 3c319ca8 2
+    │ ○  vruxwmqv hidden 7b1da5cd (no description set)
+    │ ○  vruxwmqv hidden 32eb72fe (empty) (no description set)
+    ○  zsuskuln hidden 5bf0bc06 2
+    ○    zsuskuln hidden 3027ca7a 2
     ├─╮
-    │ ○  mzvwutvl hidden 2342dbe2 (no description set)
+    │ ○  mzvwutvl hidden 8935ee61 (no description set)
     │ ○  mzvwutvl hidden 2bc3d2ce (empty) (no description set)
     ○  zsuskuln hidden cca09b4d 2
     ○  zsuskuln hidden 7b092471 (empty) 2
@@ -158,12 +158,12 @@ fn test_absorb_replace_single_line_hunk() {
     let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb"]);
     insta::assert_snapshot!(stderr, @r"
     Absorbed changes into these revisions:
-      qpvuntsm 9661b868 (conflict) 1
-    Rebased 2 descendant commits.
-    Working copy now at: zsuskuln f10b6e4e (empty) (no description set)
-    Parent commit      : kkmpptxz bed2d032 2
+      qpvuntsm 7e885236 (conflict) 1
+    Rebased 1 descendant commits.
+    Working copy now at: mzvwutvl e9c3b95b (empty) (no description set)
+    Parent commit      : kkmpptxz 7c36845c 2
     New conflicts appeared in these commits:
-      qpvuntsm 9661b868 (conflict) 1
+      qpvuntsm 7e885236 (conflict) 1
     To resolve the conflicts, start by updating to it:
       jj new qpvuntsm
     Then use `jj resolve`, or edit the conflict markers in the file directly.
@@ -172,8 +172,8 @@ fn test_absorb_replace_single_line_hunk() {
     ");
 
     insta::assert_snapshot!(get_diffs(&test_env, &repo_path, "mutable()"), @r"
-    @  zsuskuln f10b6e4e (empty) (no description set)
-    ○  kkmpptxz bed2d032 2
+    @  mzvwutvl e9c3b95b (empty) (no description set)
+    ○  kkmpptxz 7c36845c 2
     │  diff --git a/file1 b/file1
     │  index 0000000000..2f87e8e465 100644
     │  --- a/file1
@@ -189,13 +189,13 @@ fn test_absorb_replace_single_line_hunk() {
     │   1A
     │   2b
     │  ->>>>>>> Conflict 1 of 1 ends
-    ×  qpvuntsm 9661b868 (conflict) 1
+    ×  qpvuntsm 7e885236 (conflict) 1
     │  diff --git a/file1 b/file1
     ~  new file mode 100644
        index 0000000000..0000000000
        --- /dev/null
        +++ b/file1
-       @@ -1,0 +1,10 @@
+       @@ -0,0 +1,10 @@
        +<<<<<<< Conflict 1 of 1
        +%%%%%%% Changes from base to side #1
        +-2a
@@ -258,20 +258,19 @@ fn test_absorb_merge() {
     insta::assert_snapshot!(stderr, @r"
     Absorbed changes into these revisions:
       mzvwutvl e93c0210 3
-    Rebased 1 descendant commits.
-    Working copy now at: yqosqzyt 1b10dfa4 (empty) (no description set)
+    Working copy now at: vruxwmqv 1b10dfa4 (empty) (no description set)
     Parent commit      : mzvwutvl e93c0210 3
     ");
 
     insta::assert_snapshot!(get_diffs(&test_env, &repo_path, "mutable()"), @r"
-    @  yqosqzyt 1b10dfa4 (empty) (no description set)
+    @  vruxwmqv 1b10dfa4 (empty) (no description set)
     ○    mzvwutvl e93c0210 3
     ├─╮  diff --git a/file2 b/file2
     │ │  new file mode 100644
     │ │  index 0000000000..44442d2d7b
     │ │  --- /dev/null
     │ │  +++ b/file2
-    │ │  @@ -1,0 +1,1 @@
+    │ │  @@ -0,0 +1,1 @@
     │ │  +3A
     │ ○  zsuskuln 71d1ee56 2
     │ │  diff --git a/file1 b/file1
@@ -297,7 +296,86 @@ fn test_absorb_merge() {
        index 0000000000..eb6e8821f1
        --- /dev/null
        +++ b/file1
-       @@ -1,0 +1,1 @@
+       @@ -0,0 +1,1 @@
+       +0a
+    ");
+}
+
+#[test]
+fn test_absorb_discardable_merge_with_descendant() {
+    let test_env = TestEnvironment::default();
+    test_env.jj_cmd_ok(test_env.env_root(), &["git", "init", "repo"]);
+    let repo_path = test_env.env_root().join("repo");
+
+    test_env.jj_cmd_ok(&repo_path, &["describe", "-m0"]);
+    std::fs::write(repo_path.join("file1"), "0a\n").unwrap();
+
+    test_env.jj_cmd_ok(&repo_path, &["new", "-m1"]);
+    std::fs::write(repo_path.join("file1"), "1a\n1b\n0a\n").unwrap();
+
+    test_env.jj_cmd_ok(&repo_path, &["new", "-m2", "description(0)"]);
+    std::fs::write(repo_path.join("file1"), "0a\n2a\n2b\n").unwrap();
+
+    let (_stdout, stderr) =
+        test_env.jj_cmd_ok(&repo_path, &["new", "description(1)", "description(2)"]);
+    insta::assert_snapshot!(stderr, @r"
+    Working copy now at: mzvwutvl f59b2364 (empty) (no description set)
+    Parent commit      : kkmpptxz 7e9df299 1
+    Parent commit      : zsuskuln baf056cf 2
+    Added 0 files, modified 1 files, removed 0 files
+    ");
+
+    // Modify first and last lines in the merge commit
+    std::fs::write(repo_path.join("file1"), "1A\n1b\n0a\n2a\n2B\n").unwrap();
+    // Add new commit on top
+    test_env.jj_cmd_ok(&repo_path, &["new", "-m3"]);
+    std::fs::write(repo_path.join("file2"), "3a\n").unwrap();
+    // Then absorb the merge commit
+    let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb", "--from=@-"]);
+    insta::assert_snapshot!(stderr, @r"
+    Absorbed changes into these revisions:
+      zsuskuln 02668cf6 2
+      kkmpptxz fcabe394 1
+    Rebased 1 descendant commits.
+    Working copy now at: royxmykx f04f1247 3
+    Parent commit      : kkmpptxz fcabe394 1
+    Parent commit      : zsuskuln 02668cf6 2
+    ");
+
+    insta::assert_snapshot!(get_diffs(&test_env, &repo_path, "mutable()"), @r"
+    @    royxmykx f04f1247 3
+    ├─╮  diff --git a/file2 b/file2
+    │ │  new file mode 100644
+    │ │  index 0000000000..31cd755d20
+    │ │  --- /dev/null
+    │ │  +++ b/file2
+    │ │  @@ -0,0 +1,1 @@
+    │ │  +3a
+    │ ○  zsuskuln 02668cf6 2
+    │ │  diff --git a/file1 b/file1
+    │ │  index eb6e8821f1..4907935b9f 100644
+    │ │  --- a/file1
+    │ │  +++ b/file1
+    │ │  @@ -1,1 +1,3 @@
+    │ │   0a
+    │ │  +2a
+    │ │  +2B
+    ○ │  kkmpptxz fcabe394 1
+    ├─╯  diff --git a/file1 b/file1
+    │    index eb6e8821f1..902dd8ef13 100644
+    │    --- a/file1
+    │    +++ b/file1
+    │    @@ -1,1 +1,3 @@
+    │    +1A
+    │    +1b
+    │     0a
+    ○  qpvuntsm 3777b700 0
+    │  diff --git a/file1 b/file1
+    ~  new file mode 100644
+       index 0000000000..eb6e8821f1
+       --- /dev/null
+       +++ b/file1
+       @@ -0,0 +1,1 @@
        +0a
     ");
 }
@@ -314,21 +392,21 @@ fn test_absorb_conflict() {
     test_env.jj_cmd_ok(&repo_path, &["new", "root()"]);
     std::fs::write(repo_path.join("file1"), "2a\n2b\n").unwrap();
     let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["rebase", "-r@", "-ddescription(1)"]);
-    insta::assert_snapshot!(stderr, @r"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 1 commits onto destination
-    Working copy now at: kkmpptxz 24d6d0f8 (conflict) (no description set)
+    Working copy now at: kkmpptxz 74405a07 (conflict) (no description set)
     Parent commit      : qpvuntsm 3619e4e5 1
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file1    2-sided conflict
     New conflicts appeared in these commits:
-      kkmpptxz 24d6d0f8 (conflict) (no description set)
+      kkmpptxz 74405a07 (conflict) (no description set)
     To resolve the conflicts, start by updating to it:
       jj new kkmpptxz
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    ");
+    "###);
 
     let conflict_content =
         String::from_utf8(std::fs::read(repo_path.join("file1")).unwrap()).unwrap();
@@ -396,7 +474,7 @@ fn test_absorb_file_mode() {
        index 0000000000..268de3f3ec
        --- /dev/null
        +++ b/file1
-       @@ -1,0 +1,1 @@
+       @@ -0,0 +1,1 @@
        +1A
     ");
 }
@@ -456,8 +534,7 @@ fn test_absorb_from_into() {
     ");
 
     // Absorb all lines from the working-copy parent. An empty commit won't be
-    // discarded because "absorb" isn't a command to squash revisions, but to
-    // move hunks.
+    // discarded because "absorb" isn't a command to squash commit descriptions.
     let (_stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["absorb", "--from=@-"]);
     insta::assert_snapshot!(stderr, @r"
     Absorbed changes into these revisions:
@@ -488,7 +565,7 @@ fn test_absorb_from_into() {
     │  index 0000000000..faf62af049
     │  --- /dev/null
     │  +++ b/file1
-    │  @@ -1,0 +1,7 @@
+    │  @@ -0,0 +1,7 @@
     │  +1a
     │  +X
     │  +2a
@@ -544,14 +621,14 @@ fn test_absorb_paths() {
        index 0000000000..268de3f3ec
        --- /dev/null
        +++ b/file1
-       @@ -1,0 +1,1 @@
+       @@ -0,0 +1,1 @@
        +1A
        diff --git a/file2 b/file2
        new file mode 100644
        index 0000000000..a8994dc188
        --- /dev/null
        +++ b/file2
-       @@ -1,0 +1,1 @@
+       @@ -0,0 +1,1 @@
        +1a
     ");
 }
@@ -619,7 +696,7 @@ fn test_absorb_immutable() {
        index 0000000000..8c5268f893
        --- /dev/null
        +++ b/file1
-       @@ -1,0 +1,2 @@
+       @@ -0,0 +1,2 @@
        +1a
        +1b
     ");
