@@ -142,10 +142,10 @@ fn test_backout_multiple() {
     "###);
     // View the output of each backed out commit
     let stdout = test_env.jj_cmd_success(&repo_path, &["show", "@+"]);
-    insta::assert_snapshot!(stdout, @r###"
+    insta::assert_snapshot!(stdout, @r#"
     Commit ID: 8ff3fbc2ccb0d66985f558c461d1643cebb4c7d6
     Change ID: wqnwkozpkustnxypnnntnykwrqrkrpvv
-    Author: Test User <test.user@example.com> (2001-02-03 08:05:19)
+    Author   : Test User <test.user@example.com> (2001-02-03 08:05:19)
     Committer: Test User <test.user@example.com> (2001-02-03 08:05:19)
 
         Back out "e"
@@ -156,12 +156,12 @@ fn test_backout_multiple() {
        1    1: a
        2    2: b
        3     : c
-    "###);
+    "#);
     let stdout = test_env.jj_cmd_success(&repo_path, &["show", "@++"]);
-    insta::assert_snapshot!(stdout, @r###"
+    insta::assert_snapshot!(stdout, @r#"
     Commit ID: d31d42e0267f6524d445348b1dd00926c62a6b57
     Change ID: mouksmquosnpvwqrpsvvxtxpywpnxlss
-    Author: Test User <test.user@example.com> (2001-02-03 08:05:19)
+    Author   : Test User <test.user@example.com> (2001-02-03 08:05:19)
     Committer: Test User <test.user@example.com> (2001-02-03 08:05:19)
 
         Back out "c"
@@ -170,12 +170,12 @@ fn test_backout_multiple() {
 
     Removed regular file b:
        1     : b
-    "###);
+    "#);
     let stdout = test_env.jj_cmd_success(&repo_path, &["show", "@+++"]);
-    insta::assert_snapshot!(stdout, @r###"
+    insta::assert_snapshot!(stdout, @r#"
     Commit ID: 6504c4ded177fba2334f76683d1aa643700d5073
     Change ID: tqvpomtpwrqsylrpsxknultrymmqxmxv
-    Author: Test User <test.user@example.com> (2001-02-03 08:05:19)
+    Author   : Test User <test.user@example.com> (2001-02-03 08:05:19)
     Committer: Test User <test.user@example.com> (2001-02-03 08:05:19)
 
         Back out "b"
@@ -185,7 +185,7 @@ fn test_backout_multiple() {
     Modified regular file a:
        1    1: a
        2     : b
-    "###);
+    "#);
 }
 
 fn get_log_output(test_env: &TestEnvironment, cwd: &Path) -> String {
