@@ -48,9 +48,9 @@ fn test_track_untrack() {
     let stderr = test_env.jj_cmd_cli_error(&repo_path, &["file", "untrack"]);
     insta::assert_snapshot!(stderr, @r###"
     error: the following required arguments were not provided:
-      <PATHS>...
+      <FILESETS>...
 
-    Usage: jj file untrack <PATHS>...
+    Usage: jj file untrack <FILESETS>...
 
     For more information, try '--help'.
     "###);
