@@ -38,7 +38,7 @@ fn set_up() -> (TestEnvironment, PathBuf) {
         &[
             "git",
             "clone",
-            "--config-toml=git.auto-local-bookmark=true",
+            "--config=git.auto-local-bookmark=true",
             origin_git_repo_path.to_str().unwrap(),
             "local",
         ],
@@ -688,8 +688,7 @@ fn test_git_push_changes() {
         &[
             "git",
             "push",
-            "--config-toml",
-            r"git.push-bookmark-prefix='test-'",
+            "--config=git.push-bookmark-prefix=test-",
             "--change=@",
         ],
     );
@@ -706,8 +705,7 @@ fn test_git_push_changes() {
         &[
             "git",
             "push",
-            "--config-toml",
-            r"git.push-branch-prefix='branch-'",
+            "--config=git.push-branch-prefix=branch-",
             "--change=@",
         ],
     );
@@ -894,10 +892,10 @@ fn test_git_push_conflict() {
     test_env.jj_cmd_ok(&workspace_root, &["bookmark", "create", "my-bookmark"]);
     test_env.jj_cmd_ok(&workspace_root, &["describe", "-m", "third"]);
     let stderr = test_env.jj_cmd_failure(&workspace_root, &["git", "push", "--all"]);
-    insta::assert_snapshot!(stderr, @r"
-    Error: Won't push commit 73c265a92cfd since it has conflicts
-    Hint: Rejected commit: yostqsxw 73c265a9 my-bookmark | (conflict) third
-    ");
+    insta::assert_snapshot!(stderr, @r###"
+    Error: Won't push commit e2221a796300 since it has conflicts
+    Hint: Rejected commit: yostqsxw e2221a79 my-bookmark | (conflict) third
+    "###);
 }
 
 #[test]
@@ -1388,8 +1386,6 @@ fn test_git_push_moved_sideways_untracked() {
 }
 
 #[test]
-// TODO: This test fails with libgit2 v1.8.1 on Windows.
-#[cfg(not(target_os = "windows"))]
 fn test_git_push_to_remote_named_git() {
     let (test_env, workspace_root) = set_up();
     let git_repo = {
