@@ -41,9 +41,9 @@ fn test_rebase_invalid() {
     let stderr = test_env.jj_cmd_cli_error(&repo_path, &["rebase"]);
     insta::assert_snapshot!(stderr, @r###"
     error: the following required arguments were not provided:
-      <--destination <DESTINATION>|--insert-after <INSERT_AFTER>|--insert-before <INSERT_BEFORE>>
+      <--destination <REVSETS>|--insert-after <REVSETS>|--insert-before <REVSETS>>
 
-    Usage: jj rebase <--destination <DESTINATION>|--insert-after <INSERT_AFTER>|--insert-before <INSERT_BEFORE>>
+    Usage: jj rebase <--destination <REVSETS>|--insert-after <REVSETS>|--insert-before <REVSETS>>
 
     For more information, try '--help'.
     "###);
@@ -52,9 +52,9 @@ fn test_rebase_invalid() {
     let stderr =
         test_env.jj_cmd_cli_error(&repo_path, &["rebase", "-r", "a", "-s", "a", "-d", "b"]);
     insta::assert_snapshot!(stderr, @r###"
-    error: the argument '--revisions <REVISIONS>' cannot be used with '--source <SOURCE>'
+    error: the argument '--revisions <REVSETS>' cannot be used with '--source <REVSETS>'
 
-    Usage: jj rebase --revisions <REVISIONS> <--destination <DESTINATION>|--insert-after <INSERT_AFTER>|--insert-before <INSERT_BEFORE>>
+    Usage: jj rebase --revisions <REVSETS> <--destination <REVSETS>|--insert-after <REVSETS>|--insert-before <REVSETS>>
 
     For more information, try '--help'.
     "###);
@@ -63,9 +63,9 @@ fn test_rebase_invalid() {
     let stderr =
         test_env.jj_cmd_cli_error(&repo_path, &["rebase", "-b", "a", "-s", "a", "-d", "b"]);
     insta::assert_snapshot!(stderr, @r###"
-    error: the argument '--branch <BRANCH>' cannot be used with '--source <SOURCE>'
+    error: the argument '--branch <REVSETS>' cannot be used with '--source <REVSETS>'
 
-    Usage: jj rebase --branch <BRANCH> <--destination <DESTINATION>|--insert-after <INSERT_AFTER>|--insert-before <INSERT_BEFORE>>
+    Usage: jj rebase --branch <REVSETS> <--destination <REVSETS>|--insert-after <REVSETS>|--insert-before <REVSETS>>
 
     For more information, try '--help'.
     "###);
@@ -76,9 +76,9 @@ fn test_rebase_invalid() {
         &["rebase", "-r", "a", "-d", "b", "--after", "b"],
     );
     insta::assert_snapshot!(stderr, @r###"
-    error: the argument '--destination <DESTINATION>' cannot be used with '--insert-after <INSERT_AFTER>'
+    error: the argument '--destination <REVSETS>' cannot be used with '--insert-after <REVSETS>'
 
-    Usage: jj rebase --revisions <REVISIONS> <--destination <DESTINATION>|--insert-after <INSERT_AFTER>|--insert-before <INSERT_BEFORE>>
+    Usage: jj rebase --revisions <REVSETS> <--destination <REVSETS>|--insert-after <REVSETS>|--insert-before <REVSETS>>
 
     For more information, try '--help'.
     "###);
@@ -89,9 +89,9 @@ fn test_rebase_invalid() {
         &["rebase", "-r", "a", "-d", "b", "--before", "b"],
     );
     insta::assert_snapshot!(stderr, @r###"
-    error: the argument '--destination <DESTINATION>' cannot be used with '--insert-before <INSERT_BEFORE>'
+    error: the argument '--destination <REVSETS>' cannot be used with '--insert-before <REVSETS>'
 
-    Usage: jj rebase --revisions <REVISIONS> <--destination <DESTINATION>|--insert-after <INSERT_AFTER>|--insert-before <INSERT_BEFORE>>
+    Usage: jj rebase --revisions <REVSETS> <--destination <REVSETS>|--insert-after <REVSETS>|--insert-before <REVSETS>>
 
     For more information, try '--help'.
     "###);
@@ -115,6 +115,29 @@ fn test_rebase_invalid() {
     "###);
 }
 
+#[test]
+fn test_rebase_empty_sets() {
+    let test_env = TestEnvironment::default();
+    test_env.jj_cmd_ok(test_env.env_root(), &["git", "init", "repo"]);
+    let repo_path = test_env.env_root().join("repo");
+
+    create_commit(&test_env, &repo_path, "a", &[]);
+    create_commit(&test_env, &repo_path, "b", &["a"]);
+
+    // TODO: Make all of these say "Nothing changed"?
+    let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["rebase", "-r=none()", "-d=b"]);
+    insta::assert_snapshot!(stdout, @"");
+    insta::assert_snapshot!(stderr, @"Nothing changed.");
+    let stderr = test_env.jj_cmd_failure(&repo_path, &["rebase", "-s=none()", "-d=b"]);
+    insta::assert_snapshot!(stderr, @r###"Error: Revset "none()" didn't resolve to any revisions"###);
+    let stderr = test_env.jj_cmd_failure(&repo_path, &["rebase", "-b=none()", "-d=b"]);
+    insta::assert_snapshot!(stderr, @r###"Error: Revset "none()" didn't resolve to any revisions"###);
+    // Empty because "b..a" is empty
+    let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["rebase", "-b=a", "-d=b"]);
+    insta::assert_snapshot!(stdout, @"");
+    insta::assert_snapshot!(stderr, @"Nothing changed.");
+}
+
 #[test]
 fn test_rebase_bookmark() {
     let test_env = TestEnvironment::default();
@@ -720,7 +743,7 @@ fn test_rebase_multiple_destinations() {
         &repo_path,
         &[
             "rebase",
-            "--config-toml=ui.always-allow-large-revsets=true",
+            "--config=ui.always-allow-large-revsets=true",
             "-r=a",
             "-d=b|c",
         ],
@@ -897,7 +920,7 @@ fn test_rebase_error_revision_does_not_exist() {
     "###);
 }
 
-// This behavior illustrates https://github.com/martinvonz/jj/issues/2600
+// This behavior illustrates https://github.com/jj-vcs/jj/issues/2600
 #[test]
 fn test_rebase_with_child_and_descendant_bug_2600() {
     let test_env = TestEnvironment::default();
