@@ -30,34 +30,34 @@ fn test_report_conflicts() {
     let (stdout, stderr) =
         test_env.jj_cmd_ok(&repo_path, &["rebase", "-s=description(B)", "-d=root()"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 3 commits onto destination
-    Working copy now at: zsuskuln aa73e2ae (conflict) (empty) (no description set)
-    Parent commit      : kkmpptxz 64bdec0c (conflict) C
+    Working copy now at: zsuskuln f8a2c4e0 (conflict) (empty) (no description set)
+    Parent commit      : kkmpptxz 2271a49e (conflict) C
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in these commits:
-      kkmpptxz 64bdec0c (conflict) C
-      rlvkpnrz 10a5fd45 (conflict) B
+      kkmpptxz 2271a49e (conflict) C
+      rlvkpnrz b7d83633 (conflict) B
     To resolve the conflicts, start by updating to the first one:
       jj new rlvkpnrz
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["rebase", "-d=description(A)"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 3 commits onto destination
     Working copy now at: zsuskuln d70c003d (empty) (no description set)
     Parent commit      : kkmpptxz 43e94449 C
     Added 0 files, modified 1 files, removed 0 files
     Existing conflicts were resolved or abandoned from these commits:
-      kkmpptxz hidden 64bdec0c (conflict) C
-      rlvkpnrz hidden 10a5fd45 (conflict) B
-    "#);
+      kkmpptxz hidden 2271a49e (conflict) C
+      rlvkpnrz hidden b7d83633 (conflict) B
+    "###);
 
     // Can get hint about multiple root commits
     let (stdout, stderr) =
@@ -66,14 +66,14 @@ fn test_report_conflicts() {
     insta::assert_snapshot!(stderr, @r###"
     Rebased 1 commits onto destination
     Rebased 2 descendant commits
-    Working copy now at: zsuskuln 99fb9018 (conflict) (empty) (no description set)
-    Parent commit      : kkmpptxz 17c72220 (conflict) C
+    Working copy now at: zsuskuln 588bd15c (conflict) (empty) (no description set)
+    Parent commit      : kkmpptxz 331a2fce (conflict) C
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict
     New conflicts appeared in these commits:
-      kkmpptxz 17c72220 (conflict) C
-      rlvkpnrz eb93a73d (conflict) B
+      kkmpptxz 331a2fce (conflict) C
+      rlvkpnrz b42f84eb (conflict) B
     To resolve the conflicts, start by updating to one of the first ones:
       jj new kkmpptxz
       jj new rlvkpnrz
@@ -86,8 +86,8 @@ fn test_report_conflicts() {
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["new", "rlvkpnrzqnoo"]);
     insta::assert_snapshot!(stdout, @"");
     insta::assert_snapshot!(stderr, @r###"
-    Working copy now at: vruxwmqv 1d87c702 (conflict) (empty) (no description set)
-    Parent commit      : rlvkpnrz eb93a73d (conflict) B
+    Working copy now at: vruxwmqv 0485e30f (conflict) (empty) (no description set)
+    Parent commit      : rlvkpnrz b42f84eb (conflict) B
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
@@ -99,7 +99,7 @@ fn test_report_conflicts() {
     Working copy now at: yostqsxw f5a0cf8c (empty) (no description set)
     Parent commit      : rlvkpnrz 87370844 B
     Existing conflicts were resolved or abandoned from these commits:
-      rlvkpnrz hidden eb93a73d (conflict) B
+      rlvkpnrz hidden b42f84eb (conflict) B
     "###);
 }
 
@@ -121,94 +121,94 @@ fn test_report_conflicts_with_divergent_commits() {
     let (stdout, stderr) =
         test_env.jj_cmd_ok(&repo_path, &["rebase", "-s=description(B)", "-d=root()"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Concurrent modification detected, resolving automatically.
     Rebased 3 commits onto destination
-    Working copy now at: zsuskuln?? 97ce1783 (conflict) C2
-    Parent commit      : kkmpptxz eb93a73d (conflict) B
+    Working copy now at: zsuskuln?? 4ca807ad (conflict) C2
+    Parent commit      : kkmpptxz b42f84eb (conflict) B
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in these commits:
-      zsuskuln?? b535189c (conflict) C3
-      zsuskuln?? 97ce1783 (conflict) C2
-      kkmpptxz eb93a73d (conflict) B
+      zsuskuln?? 1db43f23 (conflict) C3
+      zsuskuln?? 4ca807ad (conflict) C2
+      kkmpptxz b42f84eb (conflict) B
     To resolve the conflicts, start by updating to the first one:
       jj new kkmpptxz
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["rebase", "-d=description(A)"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 3 commits onto destination
     Working copy now at: zsuskuln?? f2d7a228 C2
     Parent commit      : kkmpptxz db069a22 B
     Added 0 files, modified 1 files, removed 0 files
     Existing conflicts were resolved or abandoned from these commits:
-      zsuskuln hidden b535189c (conflict) C3
-      zsuskuln hidden 97ce1783 (conflict) C2
-      kkmpptxz hidden eb93a73d (conflict) B
-    "#);
+      zsuskuln hidden 1db43f23 (conflict) C3
+      zsuskuln hidden 4ca807ad (conflict) C2
+      kkmpptxz hidden b42f84eb (conflict) B
+    "###);
 
     // Same thing when rebasing the divergent commits one at a time
     let (stdout, stderr) =
         test_env.jj_cmd_ok(&repo_path, &["rebase", "-s=description(C2)", "-d=root()"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 1 commits onto destination
-    Working copy now at: zsuskuln?? b15416ac (conflict) C2
+    Working copy now at: zsuskuln?? 3c36afc9 (conflict) C2
     Parent commit      : zzzzzzzz 00000000 (empty) (no description set)
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict including 1 deletion
     New conflicts appeared in these commits:
-      zsuskuln?? b15416ac (conflict) C2
+      zsuskuln?? 3c36afc9 (conflict) C2
     To resolve the conflicts, start by updating to it:
       jj new zsuskuln
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
 
     let (stdout, stderr) =
         test_env.jj_cmd_ok(&repo_path, &["rebase", "-s=description(C3)", "-d=root()"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 1 commits onto destination
     New conflicts appeared in these commits:
-      zsuskuln?? 8cc7fde6 (conflict) C3
+      zsuskuln?? e3ff827e (conflict) C3
     To resolve the conflicts, start by updating to it:
       jj new zsuskuln
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(
         &repo_path,
         &["rebase", "-s=description(C2)", "-d=description(B)"],
     );
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 1 commits onto destination
     Working copy now at: zsuskuln?? 1f9680bd C2
     Parent commit      : kkmpptxz db069a22 B
     Added 0 files, modified 1 files, removed 0 files
     Existing conflicts were resolved or abandoned from these commits:
-      zsuskuln hidden b15416ac (conflict) C2
-    "#);
+      zsuskuln hidden 3c36afc9 (conflict) C2
+    "###);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(
         &repo_path,
         &["rebase", "-s=description(C3)", "-d=description(B)"],
     );
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Rebased 1 commits onto destination
     Existing conflicts were resolved or abandoned from these commits:
-      zsuskuln hidden 8cc7fde6 (conflict) C3
-    "#);
+      zsuskuln hidden e3ff827e (conflict) C3
+    "###);
 }
