@@ -125,7 +125,7 @@ fn test_resolution() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml=ui.merge-editor='false'",
+            "--config=ui.merge-editor='false'",
             "--tool=fake-editor",
         ],
     );
@@ -172,8 +172,7 @@ fn test_resolution() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml",
-            "merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
+            "--config=merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
         ],
     );
     insta::assert_snapshot!(
@@ -230,21 +229,20 @@ fn test_resolution() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml",
-            "merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
+            "--config=merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
         ],
     );
     insta::assert_snapshot!(stdout, @"");
     insta::assert_snapshot!(stderr, @r###"
     Resolving conflicts in: file
-    Working copy now at: vruxwmqv 7699b9c3 conflict | (conflict) conflict
+    Working copy now at: vruxwmqv 608a2310 conflict | (conflict) conflict
     Parent commit      : zsuskuln aa493daf a | a
     Parent commit      : royxmykx db6a4daf b | b
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict
     New conflicts appeared in these commits:
-      vruxwmqv 7699b9c3 conflict | (conflict) conflict
+      vruxwmqv 608a2310 conflict | (conflict) conflict
     To resolve the conflicts, start by updating to it:
       jj new vruxwmqv
     Then use `jj resolve`, or edit the conflict markers in the file directly.
@@ -375,31 +373,27 @@ fn test_resolution() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml",
-            r#"
-            [merge-tools.fake-editor]
-            merge-tool-edits-conflict-markers = true
-            conflict-marker-style = "git"
-            "#,
+            "--config=merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
+            "--config=merge-tools.fake-editor.conflict-marker-style=git",
         ],
     );
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Resolving conflicts in: file
-    Working copy now at: vruxwmqv 6701dfd3 conflict | (conflict) conflict
+    Working copy now at: vruxwmqv 8e03fefa conflict | (conflict) conflict
     Parent commit      : zsuskuln aa493daf a | a
     Parent commit      : royxmykx db6a4daf b | b
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict
     New conflicts appeared in these commits:
-      vruxwmqv 6701dfd3 conflict | (conflict) conflict
+      vruxwmqv 8e03fefa conflict | (conflict) conflict
     To resolve the conflicts, start by updating to it:
       jj new vruxwmqv
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor4")).unwrap(), @r##"
     <<<<<<< Side #1 (Conflict 1 of 1)
@@ -461,27 +455,26 @@ fn test_resolution() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml",
-            "merge-tools.fake-editor.merge-conflict-exit-codes = [1]",
+            "--config=merge-tools.fake-editor.merge-conflict-exit-codes=[1]",
         ],
     );
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r#"
+    insta::assert_snapshot!(stderr, @r###"
     Resolving conflicts in: file
-    Working copy now at: vruxwmqv 6690cdf4 conflict | (conflict) conflict
+    Working copy now at: vruxwmqv a786ac2f conflict | (conflict) conflict
     Parent commit      : zsuskuln aa493daf a | a
     Parent commit      : royxmykx db6a4daf b | b
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     file    2-sided conflict
     New conflicts appeared in these commits:
-      vruxwmqv 6690cdf4 conflict | (conflict) conflict
+      vruxwmqv a786ac2f conflict | (conflict) conflict
     To resolve the conflicts, start by updating to it:
       jj new vruxwmqv
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor5")).unwrap(), @"");
     insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["diff", "--git"]), 
@@ -531,8 +524,7 @@ fn test_resolution() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml",
-            "merge-tools.fake-editor.merge-conflict-exit-codes = [1]",
+            "--config=merge-tools.fake-editor.merge-conflict-exit-codes=[1]",
         ],
     );
     // On Windows, the ExitStatus struct prints "exit code" instead of "exit status"
@@ -556,7 +548,7 @@ fn check_resolve_produces_input_file(
     let editor_script = test_env.set_up_fake_editor();
     std::fs::write(editor_script, format!("expect\n{expected_content}")).unwrap();
 
-    let merge_arg_config = format!(r#"merge-tools.fake-editor.merge-args = ["${role}"]"#);
+    let merge_arg_config = format!(r#"merge-tools.fake-editor.merge-args=["${role}"]"#);
     // This error means that fake-editor exited successfully but did not modify the
     // output file.
     // We cannot use `insta::assert_snapshot!` here after insta 1.22 due to
@@ -565,7 +557,7 @@ fn check_resolve_produces_input_file(
     assert_eq!(
         test_env.jj_cmd_failure(
             repo_path,
-            &["resolve", "--config-toml", &merge_arg_config, filename]
+            &["resolve", "--config", &merge_arg_config, filename]
         ),
         format!(
             "Resolving conflicts in: {filename}\nError: Failed to resolve conflicts\nCaused by: \
@@ -778,23 +770,22 @@ fn test_simplify_conflict_sides() {
         &repo_path,
         &[
             "resolve",
-            "--config-toml",
-            "merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
+            "--config=merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
             "fileB",
         ],
     );
     insta::assert_snapshot!(stdout, @"");
     insta::assert_snapshot!(stderr, @r###"
     Resolving conflicts in: fileB
-    Working copy now at: nkmrtpmo 4b14662a conflict | (conflict) conflict
-    Parent commit      : kmkuslsw 18c1fb00 conflictA | (conflict) (empty) conflictA
-    Parent commit      : lylxulpl d11c92eb conflictB | (conflict) (empty) conflictB
+    Working copy now at: nkmrtpmo 69cc0c2d conflict | (conflict) conflict
+    Parent commit      : kmkuslsw 4601566f conflictA | (conflict) (empty) conflictA
+    Parent commit      : lylxulpl 6f8d8381 conflictB | (conflict) (empty) conflictB
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     fileA    2-sided conflict
     fileB    2-sided conflict
     New conflicts appeared in these commits:
-      nkmrtpmo 4b14662a conflict | (conflict) conflict
+      nkmrtpmo 69cc0c2d conflict | (conflict) conflict
     To resolve the conflicts, start by updating to it:
       jj new nkmrtpmo
     Then use `jj resolve`, or edit the conflict markers in the file directly.
@@ -958,6 +949,412 @@ fn test_description_with_dir_and_deletion() {
     "###);
 }
 
+#[test]
+fn test_resolve_conflicts_with_executable() {
+    let mut test_env = TestEnvironment::default();
+    test_env.jj_cmd_ok(test_env.env_root(), &["git", "init", "repo"]);
+    let repo_path = test_env.env_root().join("repo");
+
+    // Create a conflict in "file1" where all 3 terms are executables, and create a
+    // conflict in "file2" where one side set the executable bit.
+    create_commit(
+        &test_env,
+        &repo_path,
+        "base",
+        &[],
+        &[("file1", "base1\n"), ("file2", "base2\n")],
+    );
+    test_env.jj_cmd_ok(&repo_path, &["file", "chmod", "x", "file1"]);
+    create_commit(
+        &test_env,
+        &repo_path,
+        "a",
+        &["base"],
+        &[("file1", "a1\n"), ("file2", "a2\n")],
+    );
+    create_commit(
+        &test_env,
+        &repo_path,
+        "b",
+        &["base"],
+        &[("file1", "b1\n"), ("file2", "b2\n")],
+    );
+    test_env.jj_cmd_ok(&repo_path, &["file", "chmod", "x", "file2"]);
+    create_commit(&test_env, &repo_path, "conflict", &["a", "b"], &[]);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]), 
+    @r#"
+    file1    2-sided conflict including an executable
+    file2    2-sided conflict including an executable
+    "#);
+    insta::assert_snapshot!(
+        std::fs::read_to_string(repo_path.join("file1")).unwrap(),
+        @r##"
+    <<<<<<< Conflict 1 of 1
+    %%%%%%% Changes from base to side #1
+    -base1
+    +a1
+    +++++++ Contents of side #2
+    b1
+    >>>>>>> Conflict 1 of 1 ends
+    "##
+    );
+    insta::assert_snapshot!(
+        std::fs::read_to_string(repo_path.join("file2")).unwrap(),
+        @r##"
+    <<<<<<< Conflict 1 of 1
+    %%%%%%% Changes from base to side #1
+    -base2
+    +a2
+    +++++++ Contents of side #2
+    b2
+    >>>>>>> Conflict 1 of 1 ends
+    "##
+    );
+    let editor_script = test_env.set_up_fake_editor();
+
+    // Test resolving the conflict in "file1", which should produce an executable
+    std::fs::write(&editor_script, b"write\nresolution1\n").unwrap();
+    let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["resolve", "file1"]);
+    insta::assert_snapshot!(stdout, @r#""#);
+    insta::assert_snapshot!(stderr, @r#"
+    Resolving conflicts in: file1
+    Working copy now at: znkkpsqq eb159d56 conflict | (conflict) conflict
+    Parent commit      : mzvwutvl 08932848 a | a
+    Parent commit      : yqosqzyt b69b3de6 b | b
+    Added 0 files, modified 1 files, removed 0 files
+    There are unresolved conflicts at these paths:
+    file2    2-sided conflict including an executable
+    New conflicts appeared in these commits:
+      znkkpsqq eb159d56 conflict | (conflict) conflict
+    To resolve the conflicts, start by updating to it:
+      jj new znkkpsqq
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    "#);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["diff", "--git"]), 
+    @r##"
+    diff --git a/file1 b/file1
+    index 0000000000..95cc18629d 100755
+    --- a/file1
+    +++ b/file1
+    @@ -1,7 +1,1 @@
+    -<<<<<<< Conflict 1 of 1
+    -%%%%%%% Changes from base to side #1
+    --base1
+    -+a1
+    -+++++++ Contents of side #2
+    -b1
+    ->>>>>>> Conflict 1 of 1 ends
+    +resolution1
+    "##);
+    insta::assert_snapshot!(
+        test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]),
+        @"file2    2-sided conflict including an executable"
+    );
+
+    // Test resolving the conflict in "file2", which should produce an executable
+    test_env.jj_cmd_ok(&repo_path, &["undo"]);
+    std::fs::write(&editor_script, b"write\nresolution2\n").unwrap();
+    let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["resolve", "file2"]);
+    insta::assert_snapshot!(stdout, @r#""#);
+    insta::assert_snapshot!(stderr, @r#"
+    Resolving conflicts in: file2
+    Working copy now at: znkkpsqq 4dccbb3c conflict | (conflict) conflict
+    Parent commit      : mzvwutvl 08932848 a | a
+    Parent commit      : yqosqzyt b69b3de6 b | b
+    Added 0 files, modified 1 files, removed 0 files
+    There are unresolved conflicts at these paths:
+    file1    2-sided conflict including an executable
+    New conflicts appeared in these commits:
+      znkkpsqq 4dccbb3c conflict | (conflict) conflict
+    To resolve the conflicts, start by updating to it:
+      jj new znkkpsqq
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    "#);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["diff", "--git"]), 
+    @r##"
+    diff --git a/file2 b/file2
+    index 0000000000..775f078581 100755
+    --- a/file2
+    +++ b/file2
+    @@ -1,7 +1,1 @@
+    -<<<<<<< Conflict 1 of 1
+    -%%%%%%% Changes from base to side #1
+    --base2
+    -+a2
+    -+++++++ Contents of side #2
+    -b2
+    ->>>>>>> Conflict 1 of 1 ends
+    +resolution2
+    "##);
+    insta::assert_snapshot!(
+        test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]),
+        @"file1    2-sided conflict including an executable"
+    );
+}
+
+#[test]
+fn test_resolve_long_conflict_markers() {
+    let mut test_env = TestEnvironment::default();
+    test_env.jj_cmd_ok(test_env.env_root(), &["git", "init", "repo"]);
+    let repo_path = test_env.env_root().join("repo");
+
+    // Makes it easier to read the diffs between conflicts
+    test_env.add_config("ui.conflict-marker-style = 'snapshot'");
+
+    // Create a conflict which requires long conflict markers to be materialized
+    create_commit(
+        &test_env,
+        &repo_path,
+        "base",
+        &[],
+        &[("file", "======= base\n")],
+    );
+    create_commit(
+        &test_env,
+        &repo_path,
+        "a",
+        &["base"],
+        &[("file", "<<<<<<< a\n")],
+    );
+    create_commit(
+        &test_env,
+        &repo_path,
+        "b",
+        &["base"],
+        &[("file", ">>>>>>> b\n")],
+    );
+    create_commit(&test_env, &repo_path, "conflict", &["a", "b"], &[]);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]), 
+    @"file    2-sided conflict");
+    insta::assert_snapshot!(
+        std::fs::read_to_string(repo_path.join("file")).unwrap(),
+        @r##"
+    <<<<<<<<<<< Conflict 1 of 1
+    +++++++++++ Contents of side #1
+    <<<<<<< a
+    ----------- Contents of base
+    ======= base
+    +++++++++++ Contents of side #2
+    >>>>>>> b
+    >>>>>>>>>>> Conflict 1 of 1 ends
+    "##
+    );
+    let editor_script = test_env.set_up_fake_editor();
+    // Allow signaling that conflict markers were produced even if not editing
+    // conflict markers materialized in the output file
+    test_env.add_config("merge-tools.fake-editor.merge-conflict-exit-codes = [1]");
+
+    // By default, conflict markers of length 7 or longer are parsed for
+    // compatibility with Git merge tools
+    std::fs::write(
+        &editor_script,
+        indoc! {b"
+        write
+        <<<<<<<
+        A
+        |||||||
+        BASE
+        =======
+        B
+        >>>>>>>
+        \0fail
+        "},
+    )
+    .unwrap();
+    let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["resolve"]);
+    insta::assert_snapshot!(stdout, @r#""#);
+    insta::assert_snapshot!(stderr, @r#"
+    Resolving conflicts in: file
+    Working copy now at: vruxwmqv 2b985546 conflict | (conflict) conflict
+    Parent commit      : zsuskuln 64177fd4 a | a
+    Parent commit      : royxmykx db442c1e b | b
+    Added 0 files, modified 1 files, removed 0 files
+    There are unresolved conflicts at these paths:
+    file    2-sided conflict
+    New conflicts appeared in these commits:
+      vruxwmqv 2b985546 conflict | (conflict) conflict
+    To resolve the conflicts, start by updating to it:
+      jj new vruxwmqv
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    "#);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["diff", "--git"]), 
+    @r##"
+    diff --git a/file b/file
+    --- a/file
+    +++ b/file
+    @@ -1,8 +1,8 @@
+    -<<<<<<<<<<< Conflict 1 of 1
+    -+++++++++++ Contents of side #1
+    -<<<<<<< a
+    ------------ Contents of base
+    -======= base
+    -+++++++++++ Contents of side #2
+    ->>>>>>> b
+    ->>>>>>>>>>> Conflict 1 of 1 ends
+    +<<<<<<< Conflict 1 of 1
+    ++++++++ Contents of side #1
+    +A
+    +------- Contents of base
+    +BASE
+    ++++++++ Contents of side #2
+    +B
+    +>>>>>>> Conflict 1 of 1 ends
+    "##);
+    insta::assert_snapshot!(
+        test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]),
+        @"file    2-sided conflict"
+    );
+
+    // If the merge tool edits the output file with materialized markers, the
+    // markers must match the length of the materialized markers to be parsed
+    test_env.jj_cmd_ok(&repo_path, &["undo"]);
+    std::fs::write(
+        &editor_script,
+        indoc! {b"
+        dump editor
+        \0write
+        <<<<<<<<<<<
+        <<<<<<< A
+        |||||||||||
+        ======= BASE
+        ===========
+        >>>>>>> B
+        >>>>>>>>>>>
+        \0fail
+        "},
+    )
+    .unwrap();
+    let (stdout, stderr) = test_env.jj_cmd_ok(
+        &repo_path,
+        &[
+            "resolve",
+            "--config=merge-tools.fake-editor.merge-tool-edits-conflict-markers=true",
+        ],
+    );
+    insta::assert_snapshot!(stdout, @r#""#);
+    insta::assert_snapshot!(stderr, @r#"
+    Resolving conflicts in: file
+    Working copy now at: vruxwmqv fac9406d conflict | (conflict) conflict
+    Parent commit      : zsuskuln 64177fd4 a | a
+    Parent commit      : royxmykx db442c1e b | b
+    Added 0 files, modified 1 files, removed 0 files
+    There are unresolved conflicts at these paths:
+    file    2-sided conflict
+    New conflicts appeared in these commits:
+      vruxwmqv fac9406d conflict | (conflict) conflict
+    To resolve the conflicts, start by updating to it:
+      jj new vruxwmqv
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    "#);
+    insta::assert_snapshot!(
+        std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r##"
+    <<<<<<<<<<< Conflict 1 of 1
+    +++++++++++ Contents of side #1
+    <<<<<<< a
+    ----------- Contents of base
+    ======= base
+    +++++++++++ Contents of side #2
+    >>>>>>> b
+    >>>>>>>>>>> Conflict 1 of 1 ends
+    "##);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["diff", "--git"]), 
+    @r##"
+    diff --git a/file b/file
+    --- a/file
+    +++ b/file
+    @@ -1,8 +1,8 @@
+     <<<<<<<<<<< Conflict 1 of 1
+     +++++++++++ Contents of side #1
+    -<<<<<<< a
+    +<<<<<<< A
+     ----------- Contents of base
+    -======= base
+    +======= BASE
+     +++++++++++ Contents of side #2
+    ->>>>>>> b
+    +>>>>>>> B
+     >>>>>>>>>>> Conflict 1 of 1 ends
+    "##);
+    insta::assert_snapshot!(
+        test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]),
+        @"file    2-sided conflict"
+    );
+
+    // If the merge tool accepts the marker length as an argument, then the conflict
+    // markers should be at least as long as "$marker_length"
+    test_env.jj_cmd_ok(&repo_path, &["undo"]);
+    std::fs::write(
+        &editor_script,
+        indoc! {b"
+        expect-arg 0
+        11\0write
+        <<<<<<<<<<<
+        <<<<<<< A
+        |||||||||||
+        ======= BASE
+        ===========
+        >>>>>>> B
+        >>>>>>>>>>>
+        \0fail
+        "},
+    )
+    .unwrap();
+    let (stdout, stderr) = test_env.jj_cmd_ok(
+        &repo_path,
+        &[
+            "resolve",
+            r#"--config=merge-tools.fake-editor.merge-args=["$output", "$marker_length"]"#,
+        ],
+    );
+    insta::assert_snapshot!(stdout, @r#""#);
+    insta::assert_snapshot!(stderr, @r#"
+    Resolving conflicts in: file
+    Working copy now at: vruxwmqv 1b29631a conflict | (conflict) conflict
+    Parent commit      : zsuskuln 64177fd4 a | a
+    Parent commit      : royxmykx db442c1e b | b
+    Added 0 files, modified 1 files, removed 0 files
+    There are unresolved conflicts at these paths:
+    file    2-sided conflict
+    New conflicts appeared in these commits:
+      vruxwmqv 1b29631a conflict | (conflict) conflict
+    To resolve the conflicts, start by updating to it:
+      jj new vruxwmqv
+    Then use `jj resolve`, or edit the conflict markers in the file directly.
+    Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
+    Then run `jj squash` to move the resolution into the conflicted commit.
+    "#);
+    insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["diff", "--git"]), 
+    @r##"
+    diff --git a/file b/file
+    --- a/file
+    +++ b/file
+    @@ -1,8 +1,8 @@
+     <<<<<<<<<<< Conflict 1 of 1
+     +++++++++++ Contents of side #1
+    -<<<<<<< a
+    +<<<<<<< A
+     ----------- Contents of base
+    -======= base
+    +======= BASE
+     +++++++++++ Contents of side #2
+    ->>>>>>> b
+    +>>>>>>> B
+     >>>>>>>>>>> Conflict 1 of 1 ends
+    "##);
+    insta::assert_snapshot!(
+        test_env.jj_cmd_success(&repo_path, &["resolve", "--list"]),
+        @"file    2-sided conflict"
+    );
+}
+
 #[test]
 fn test_multiple_conflicts() {
     let mut test_env = TestEnvironment::default();
@@ -1056,14 +1453,14 @@ fn test_multiple_conflicts() {
     insta::assert_snapshot!(stdout, @"");
     insta::assert_snapshot!(stderr, @r###"
     Resolving conflicts in: another_file
-    Working copy now at: vruxwmqv 6a90e546 conflict | (conflict) conflict
+    Working copy now at: vruxwmqv 309e981c conflict | (conflict) conflict
     Parent commit      : zsuskuln de7553ef a | a
     Parent commit      : royxmykx f68bc2f0 b | b
     Added 0 files, modified 1 files, removed 0 files
     There are unresolved conflicts at these paths:
     this_file_has_a_very_long_name_to_test_padding 2-sided conflict
     New conflicts appeared in these commits:
-      vruxwmqv 6a90e546 conflict | (conflict) conflict
+      vruxwmqv 309e981c conflict | (conflict) conflict
     To resolve the conflicts, start by updating to it:
       jj new vruxwmqv
     Then use `jj resolve`, or edit the conflict markers in the file directly.
