@@ -93,7 +93,7 @@ fn test_status_merge() {
     "###);
 }
 
-// See https://github.com/martinvonz/jj/issues/2051.
+// See https://github.com/jj-vcs/jj/issues/2051.
 #[test]
 fn test_status_ignored_gitignore() {
     let test_env = TestEnvironment::default();
@@ -137,8 +137,8 @@ fn test_status_filtered() {
     "###);
 }
 
-// See <https://github.com/martinvonz/jj/issues/3108>
-// See <https://github.com/martinvonz/jj/issues/4147>
+// See <https://github.com/jj-vcs/jj/issues/3108>
+// See <https://github.com/jj-vcs/jj/issues/4147>
 #[test]
 fn test_status_display_relevant_working_commit_conflict_hints() {
     let test_env = TestEnvironment::default();
@@ -180,11 +180,11 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
     let stdout = test_env.jj_cmd_success(&repo_path, &["log", "-r", "::"]);
 
     insta::assert_snapshot!(stdout, @r###"
-    @  yqosqzyt test.user@example.com 2001-02-03 08:05:13 65143fef conflict
+    @  yqosqzyt test.user@example.com 2001-02-03 08:05:13 dcb25635 conflict
     │  (empty) boom-cont-2
-    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 a4e88714 conflict
+    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 664a4c6c conflict
     │  (empty) boom-cont
-    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 538415e7 conflict
+    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 c5a4e9cb conflict
     ├─╮  (empty) boom
     │ ○  kkmpptxz test.user@example.com 2001-02-03 08:05:10 1e8c2956
     │ │  First part of conflicting change
@@ -197,18 +197,18 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
 
     let stdout = test_env.jj_cmd_success(&repo_path, &["status"]);
 
-    insta::assert_snapshot!(stdout, @r#"
+    insta::assert_snapshot!(stdout, @r###"
     The working copy is clean
     There are unresolved conflicts at these paths:
     conflicted.txt    2-sided conflict
-    Working copy : yqosqzyt 65143fef (conflict) (empty) boom-cont-2
-    Parent commit: royxmykx a4e88714 (conflict) (empty) boom-cont
+    Working copy : yqosqzyt dcb25635 (conflict) (empty) boom-cont-2
+    Parent commit: royxmykx 664a4c6c (conflict) (empty) boom-cont
     To resolve the conflicts, start by updating to the first one:
       jj new mzvwutvl
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
 
     // Resolve conflict
     test_env.jj_cmd_ok(&repo_path, &["new", "--message", "fixed 1"]);
@@ -222,15 +222,15 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
     let stdout = test_env.jj_cmd_success(&repo_path, &["log", "-r", "::"]);
 
     insta::assert_snapshot!(stdout, @r###"
-    @  kpqxywon test.user@example.com 2001-02-03 08:05:18 3432159f
+    @  kpqxywon test.user@example.com 2001-02-03 08:05:18 d313f2e1
     │  fixed 2
-    ○  znkkpsqq test.user@example.com 2001-02-03 08:05:17 897d589f
+    ○  znkkpsqq test.user@example.com 2001-02-03 08:05:17 23e58975
     │  fixed 1
-    ×  yqosqzyt test.user@example.com 2001-02-03 08:05:13 65143fef conflict
+    ×  yqosqzyt test.user@example.com 2001-02-03 08:05:13 dcb25635 conflict
     │  (empty) boom-cont-2
-    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 a4e88714 conflict
+    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 664a4c6c conflict
     │  (empty) boom-cont
-    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 538415e7 conflict
+    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 c5a4e9cb conflict
     ├─╮  (empty) boom
     │ ○  kkmpptxz test.user@example.com 2001-02-03 08:05:10 1e8c2956
     │ │  First part of conflicting change
@@ -246,8 +246,8 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
     insta::assert_snapshot!(stdout, @r###"
     Working copy changes:
     M conflicted.txt
-    Working copy : kpqxywon 3432159f fixed 2
-    Parent commit: znkkpsqq 897d589f fixed 1
+    Working copy : kpqxywon d313f2e1 fixed 2
+    Parent commit: znkkpsqq 23e58975 fixed 1
     "###);
 
     // Step back one.
@@ -256,15 +256,15 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
     let stdout = test_env.jj_cmd_success(&repo_path, &["log", "-r", "::"]);
 
     insta::assert_snapshot!(stdout, @r###"
-    ○  kpqxywon test.user@example.com 2001-02-03 08:05:18 3432159f
+    ○  kpqxywon test.user@example.com 2001-02-03 08:05:18 d313f2e1
     │  fixed 2
-    @  znkkpsqq test.user@example.com 2001-02-03 08:05:17 897d589f
+    @  znkkpsqq test.user@example.com 2001-02-03 08:05:17 23e58975
     │  fixed 1
-    ×  yqosqzyt test.user@example.com 2001-02-03 08:05:13 65143fef conflict
+    ×  yqosqzyt test.user@example.com 2001-02-03 08:05:13 dcb25635 conflict
     │  (empty) boom-cont-2
-    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 a4e88714 conflict
+    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 664a4c6c conflict
     │  (empty) boom-cont
-    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 538415e7 conflict
+    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 c5a4e9cb conflict
     ├─╮  (empty) boom
     │ ○  kkmpptxz test.user@example.com 2001-02-03 08:05:10 1e8c2956
     │ │  First part of conflicting change
@@ -280,8 +280,8 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
     insta::assert_snapshot!(stdout, @r###"
     Working copy changes:
     M conflicted.txt
-    Working copy : znkkpsqq 897d589f fixed 1
-    Parent commit: yqosqzyt 65143fef (conflict) (empty) boom-cont-2
+    Working copy : znkkpsqq 23e58975 fixed 1
+    Parent commit: yqosqzyt dcb25635 (conflict) (empty) boom-cont-2
     Conflict in parent commit has been resolved in working copy
     "###);
 
@@ -292,15 +292,15 @@ fn test_status_display_relevant_working_commit_conflict_hints() {
     let stdout = test_env.jj_cmd_success(&repo_path, &["log", "-r", "::"]);
 
     insta::assert_snapshot!(stdout, @r###"
-    ○  kpqxywon test.user@example.com 2001-02-03 08:05:18 3432159f
+    ○  kpqxywon test.user@example.com 2001-02-03 08:05:18 d313f2e1
     │  fixed 2
-    ○  znkkpsqq test.user@example.com 2001-02-03 08:05:17 897d589f
+    ○  znkkpsqq test.user@example.com 2001-02-03 08:05:17 23e58975
     │  fixed 1
-    ×  yqosqzyt test.user@example.com 2001-02-03 08:05:13 65143fef conflict
+    ×  yqosqzyt test.user@example.com 2001-02-03 08:05:13 dcb25635 conflict
     │  (empty) boom-cont-2
-    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 a4e88714 conflict
+    ×  royxmykx test.user@example.com 2001-02-03 08:05:12 664a4c6c conflict
     │  (empty) boom-cont
-    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 538415e7 conflict
+    ×    mzvwutvl test.user@example.com 2001-02-03 08:05:11 c5a4e9cb conflict
     ├─╮  (empty) boom
     │ ○  kkmpptxz test.user@example.com 2001-02-03 08:05:10 1e8c2956
     │ │  First part of conflicting change
@@ -352,19 +352,19 @@ fn test_status_simplify_conflict_sides() {
     );
 
     insta::assert_snapshot!(test_env.jj_cmd_success(&repo_path, &["status"]),
-    @r#"
+    @r###"
     The working copy is clean
     There are unresolved conflicts at these paths:
     fileA    2-sided conflict
     fileB    2-sided conflict
-    Working copy : nkmrtpmo 7b1cdcaa conflict | (conflict) (empty) conflict
-    Parent commit: kmkuslsw 18c1fb00 conflictA | (conflict) (empty) conflictA
-    Parent commit: lylxulpl d11c92eb conflictB | (conflict) (empty) conflictB
+    Working copy : nkmrtpmo 83c4b9e7 conflict | (conflict) (empty) conflict
+    Parent commit: kmkuslsw 4601566f conflictA | (conflict) (empty) conflictA
+    Parent commit: lylxulpl 6f8d8381 conflictB | (conflict) (empty) conflictB
     To resolve the conflicts, start by updating to one of the first ones:
       jj new lylxulpl
       jj new kmkuslsw
     Then use `jj resolve`, or edit the conflict markers in the file directly.
     Once the conflicts are resolved, you may want to inspect the result with `jj diff`.
     Then run `jj squash` to move the resolution into the conflicted commit.
-    "#);
+    "###);
 }
