@@ -109,8 +109,8 @@ fn test_bad_locking_children(backend: TestRepoBackend) {
     let repo = &test_workspace.repo;
     let workspace_root = test_workspace.workspace.workspace_root();
 
-    let mut tx = repo.start_transaction(&settings);
-    let initial = create_random_commit(tx.repo_mut(), &settings)
+    let mut tx = repo.start_transaction();
+    let initial = create_random_commit(tx.repo_mut())
         .set_parents(vec![repo.store().root_commit_id().clone()])
         .write()
         .unwrap();
@@ -126,12 +126,9 @@ fn test_bad_locking_children(backend: TestRepoBackend) {
         &default_working_copy_factories(),
     )
     .unwrap();
-    let machine1_repo = machine1_workspace
-        .repo_loader()
-        .load_at_head(&settings)
-        .unwrap();
-    let mut machine1_tx = machine1_repo.start_transaction(&settings);
-    let child1 = create_random_commit(machine1_tx.repo_mut(), &settings)
+    let machine1_repo = machine1_workspace.repo_loader().load_at_head().unwrap();
+    let mut machine1_tx = machine1_repo.start_transaction();
+    let child1 = create_random_commit(machine1_tx.repo_mut())
         .set_parents(vec![initial.id().clone()])
         .write()
         .unwrap();
@@ -147,12 +144,9 @@ fn test_bad_locking_children(backend: TestRepoBackend) {
         &default_working_copy_factories(),
     )
     .unwrap();
-    let machine2_repo = machine2_workspace
-        .repo_loader()
-        .load_at_head(&settings)
-        .unwrap();
-    let mut machine2_tx = machine2_repo.start_transaction(&settings);
-    let child2 = create_random_commit(machine2_tx.repo_mut(), &settings)
+    let machine2_repo = machine2_workspace.repo_loader().load_at_head().unwrap();
+    let mut machine2_tx = machine2_repo.start_transaction();
+    let child2 = create_random_commit(machine2_tx.repo_mut())
         .set_parents(vec![initial.id().clone()])
         .write()
         .unwrap();
@@ -169,10 +163,7 @@ fn test_bad_locking_children(backend: TestRepoBackend) {
         &default_working_copy_factories(),
     )
     .unwrap();
-    let merged_repo = merged_workspace
-        .repo_loader()
-        .load_at_head(&settings)
-        .unwrap();
+    let merged_repo = merged_workspace.repo_loader().load_at_head().unwrap();
     assert!(merged_repo.view().heads().contains(child1.id()));
     assert!(merged_repo.view().heads().contains(child2.id()));
     let op_id = merged_repo.op_id().clone();
@@ -191,8 +182,8 @@ fn test_bad_locking_interrupted(backend: TestRepoBackend) {
     let test_env = &test_workspace.env;
     let repo = &test_workspace.repo;
 
-    let mut tx = repo.start_transaction(&settings);
-    let initial = create_random_commit(tx.repo_mut(), &settings)
+    let mut tx = repo.start_transaction();
+    let initial = create_random_commit(tx.repo_mut())
         .set_parents(vec![repo.store().root_commit_id().clone()])
         .write()
         .unwrap();
@@ -205,8 +196,8 @@ fn test_bad_locking_interrupted(backend: TestRepoBackend) {
     let op_heads_dir = test_workspace.repo_path().join("op_heads");
     let backup_path = test_workspace.root_dir().join("backup");
     copy_directory(&op_heads_dir, &backup_path);
-    let mut tx = repo.start_transaction(&settings);
-    create_random_commit(tx.repo_mut(), &settings)
+    let mut tx = repo.start_transaction();
+    create_random_commit(tx.repo_mut())
         .set_parents(vec![initial.id().clone()])
         .write()
         .unwrap();
