@@ -38,14 +38,11 @@ use testutils::TestRepoBackend;
 
 fn config_with_commit_timestamp(timestamp: &str) -> StackedConfig {
     let mut config = testutils::base_user_config();
-    config.add_layer(ConfigLayer::with_data(
-        ConfigSource::User,
-        config::Config::builder()
-            .set_override("debug.commit-timestamp", timestamp)
-            .unwrap()
-            .build()
-            .unwrap(),
-    ));
+    let mut layer = ConfigLayer::empty(ConfigSource::User);
+    layer
+        .set_value("debug.commit-timestamp", timestamp)
+        .unwrap();
+    config.add_layer(layer);
     config
 }
 
@@ -67,7 +64,6 @@ fn to_owned_path_vec(paths: &[&RepoPath]) -> Vec<RepoPathBuf> {
 #[test_case(TestRepoBackend::Local ; "local backend")]
 #[test_case(TestRepoBackend::Git ; "git backend")]
 fn test_initial(backend: TestRepoBackend) {
-    let settings = testutils::user_settings();
     let test_repo = TestRepo::init_with_backend(backend);
     let repo = &test_repo.repo;
     let store = repo.store();
@@ -82,7 +78,7 @@ fn test_initial(backend: TestRepoBackend) {
         ],
     );
 
-    let mut tx = repo.start_transaction(&settings);
+    let mut tx = repo.start_transaction();
     let author_signature = Signature {
         name: "author name".to_string(),
         email: "author email".to_string(),
@@ -102,7 +98,7 @@ fn test_initial(backend: TestRepoBackend) {
     let change_id = ChangeId::new(vec![100u8; 16]);
     let builder = tx
         .repo_mut()
-        .new_commit(&settings, vec![store.root_commit_id().clone()], tree.id())
+        .new_commit(vec![store.root_commit_id().clone()], tree.id())
         .set_change_id(change_id.clone())
         .set_description("description")
         .set_author(author_signature.clone())
@@ -135,9 +131,10 @@ fn test_initial(backend: TestRepoBackend) {
 #[test_case(TestRepoBackend::Git ; "git backend")]
 fn test_rewrite(backend: TestRepoBackend) {
     let settings = testutils::user_settings();
-    let test_repo = TestRepo::init_with_backend(backend);
+    let test_repo = TestRepo::init_with_backend_and_settings(backend, &settings);
+    let test_env = &test_repo.env;
     let repo = &test_repo.repo;
-    let store = repo.store().clone();
+    let store = repo.store();
 
     let root_file_path = RepoPath::from_internal_string("file");
     let dir_file_path = RepoPath::from_internal_string("dir/file");
@@ -149,14 +146,10 @@ fn test_rewrite(backend: TestRepoBackend) {
         ],
     );
 
-    let mut tx = repo.start_transaction(&settings);
+    let mut tx = repo.start_transaction();
     let initial_commit = tx
         .repo_mut()
-        .new_commit(
-            &settings,
-            vec![store.root_commit_id().clone()],
-            initial_tree.id(),
-        )
+        .new_commit(vec![store.root_commit_id().clone()], initial_tree.id())
         .write()
         .unwrap();
     let repo = tx.commit("test").unwrap();
@@ -169,7 +162,7 @@ fn test_rewrite(backend: TestRepoBackend) {
         ],
     );
 
-    let mut config = StackedConfig::empty();
+    let mut config = StackedConfig::with_defaults();
     config.add_layer(
         ConfigLayer::parse(
             ConfigSource::User,
@@ -180,15 +173,18 @@ fn test_rewrite(backend: TestRepoBackend) {
         )
         .unwrap(),
     );
-    let rewrite_settings = UserSettings::from_config(config);
-    let mut tx = repo.start_transaction(&settings);
+    let rewrite_settings = UserSettings::from_config(config).unwrap();
+    let repo = test_env.load_repo_at_head(&rewrite_settings, test_repo.repo_path());
+    let store = repo.store();
+    let initial_commit = store.get_commit(initial_commit.id()).unwrap();
+    let mut tx = repo.start_transaction();
     let rewritten_commit = tx
         .repo_mut()
-        .rewrite_commit(&rewrite_settings, &initial_commit)
+        .rewrite_commit(&initial_commit)
         .set_tree_id(rewritten_tree.id().clone())
         .write()
         .unwrap();
-    tx.repo_mut().rebase_descendants(&settings).unwrap();
+    tx.repo_mut().rebase_descendants().unwrap();
     tx.commit("test").unwrap();
     let parents: Vec<_> = rewritten_commit.parents().try_collect().unwrap();
     assert_eq!(parents, vec![store.root_commit()]);
@@ -224,15 +220,15 @@ fn test_rewrite(backend: TestRepoBackend) {
 #[test_case(TestRepoBackend::Local ; "local backend")]
 #[test_case(TestRepoBackend::Git ; "git backend")]
 fn test_rewrite_update_missing_user(backend: TestRepoBackend) {
-    let missing_user_settings = UserSettings::from_config(StackedConfig::empty());
-    let test_repo = TestRepo::init_with_backend(backend);
+    let missing_user_settings = UserSettings::from_config(StackedConfig::with_defaults()).unwrap();
+    let test_repo = TestRepo::init_with_backend_and_settings(backend, &missing_user_settings);
+    let test_env = &test_repo.env;
     let repo = &test_repo.repo;
 
-    let mut tx = repo.start_transaction(&missing_user_settings);
+    let mut tx = repo.start_transaction();
     let initial_commit = tx
         .repo_mut()
         .new_commit(
-            &missing_user_settings,
             vec![repo.store().root_commit_id().clone()],
             repo.store().empty_merged_tree_id(),
         )
@@ -242,8 +238,9 @@ fn test_rewrite_update_missing_user(backend: TestRepoBackend) {
     assert_eq!(initial_commit.author().email, "");
     assert_eq!(initial_commit.committer().name, "");
     assert_eq!(initial_commit.committer().email, "");
+    tx.commit("test").unwrap();
 
-    let mut config = StackedConfig::empty();
+    let mut config = StackedConfig::with_defaults();
     config.add_layer(
         ConfigLayer::parse(
             ConfigSource::User,
@@ -254,10 +251,13 @@ fn test_rewrite_update_missing_user(backend: TestRepoBackend) {
         )
         .unwrap(),
     );
-    let settings = UserSettings::from_config(config);
+    let settings = UserSettings::from_config(config).unwrap();
+    let repo = test_env.load_repo_at_head(&settings, test_repo.repo_path());
+    let initial_commit = repo.store().get_commit(initial_commit.id()).unwrap();
+    let mut tx = repo.start_transaction();
     let rewritten_commit = tx
         .repo_mut()
-        .rewrite_commit(&settings, &initial_commit)
+        .rewrite_commit(&initial_commit)
         .write()
         .unwrap();
 
@@ -277,21 +277,23 @@ fn test_rewrite_update_missing_user(backend: TestRepoBackend) {
 #[test_case(TestRepoBackend::Git ; "git backend")]
 fn test_rewrite_resets_author_timestamp(backend: TestRepoBackend) {
     let test_repo = TestRepo::init_with_backend(backend);
-    let repo = &test_repo.repo;
+    let test_env = &test_repo.env;
 
     // Create discardable commit
     let initial_timestamp = "2001-02-03T04:05:06+07:00";
-    let settings = UserSettings::from_config(config_with_commit_timestamp(initial_timestamp));
-    let mut tx = repo.start_transaction(&settings);
+    let settings =
+        UserSettings::from_config(config_with_commit_timestamp(initial_timestamp)).unwrap();
+    let repo = test_env.load_repo_at_head(&settings, test_repo.repo_path());
+    let mut tx = repo.start_transaction();
     let initial_commit = tx
         .repo_mut()
         .new_commit(
-            &settings,
             vec![repo.store().root_commit_id().clone()],
             repo.store().empty_merged_tree_id(),
         )
         .write()
         .unwrap();
+    tx.commit("test").unwrap();
 
     let initial_timestamp =
         Timestamp::from_datetime(chrono::DateTime::parse_from_rfc3339(initial_timestamp).unwrap());
@@ -300,13 +302,19 @@ fn test_rewrite_resets_author_timestamp(backend: TestRepoBackend) {
 
     // Rewrite discardable commit to no longer be discardable
     let new_timestamp_1 = "2002-03-04T05:06:07+08:00";
-    let settings = UserSettings::from_config(config_with_commit_timestamp(new_timestamp_1));
+    let settings =
+        UserSettings::from_config(config_with_commit_timestamp(new_timestamp_1)).unwrap();
+    let repo = test_env.load_repo_at_head(&settings, test_repo.repo_path());
+    let initial_commit = repo.store().get_commit(initial_commit.id()).unwrap();
+    let mut tx = repo.start_transaction();
     let rewritten_commit_1 = tx
         .repo_mut()
-        .rewrite_commit(&settings, &initial_commit)
+        .rewrite_commit(&initial_commit)
         .set_description("No longer discardable")
         .write()
         .unwrap();
+    tx.repo_mut().rebase_descendants().unwrap();
+    tx.commit("test").unwrap();
 
     let new_timestamp_1 =
         Timestamp::from_datetime(chrono::DateTime::parse_from_rfc3339(new_timestamp_1).unwrap());
@@ -318,13 +326,19 @@ fn test_rewrite_resets_author_timestamp(backend: TestRepoBackend) {
 
     // Rewrite non-discardable commit
     let new_timestamp_2 = "2003-04-05T06:07:08+09:00";
-    let settings = UserSettings::from_config(config_with_commit_timestamp(new_timestamp_2));
+    let settings =
+        UserSettings::from_config(config_with_commit_timestamp(new_timestamp_2)).unwrap();
+    let repo = test_env.load_repo_at_head(&settings, test_repo.repo_path());
+    let rewritten_commit_1 = repo.store().get_commit(rewritten_commit_1.id()).unwrap();
+    let mut tx = repo.start_transaction();
     let rewritten_commit_2 = tx
         .repo_mut()
-        .rewrite_commit(&settings, &rewritten_commit_1)
+        .rewrite_commit(&rewritten_commit_1)
         .set_description("New description")
         .write()
         .unwrap();
+    tx.repo_mut().rebase_descendants().unwrap();
+    tx.commit("test").unwrap();
 
     let new_timestamp_2 =
         Timestamp::from_datetime(chrono::DateTime::parse_from_rfc3339(new_timestamp_2).unwrap());
@@ -337,23 +351,21 @@ fn test_rewrite_resets_author_timestamp(backend: TestRepoBackend) {
 #[test_case(TestRepoBackend::Local ; "local backend")]
 // #[test_case(TestRepoBackend::Git ; "git backend")]
 fn test_commit_builder_descendants(backend: TestRepoBackend) {
-    let settings = testutils::user_settings();
     let test_repo = TestRepo::init_with_backend(backend);
     let repo = &test_repo.repo;
     let store = repo.store().clone();
 
-    let mut tx = repo.start_transaction(&settings);
-    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.repo_mut());
+    let mut tx = repo.start_transaction();
+    let mut graph_builder = CommitGraphBuilder::new(tx.repo_mut());
     let commit1 = graph_builder.initial_commit();
     let commit2 = graph_builder.commit_with_parents(&[&commit1]);
     let commit3 = graph_builder.commit_with_parents(&[&commit2]);
     let repo = tx.commit("test").unwrap();
 
     // Test with for_new_commit()
-    let mut tx = repo.start_transaction(&settings);
+    let mut tx = repo.start_transaction();
     tx.repo_mut()
         .new_commit(
-            &settings,
             vec![store.root_commit_id().clone()],
             store.empty_merged_tree_id(),
         )
@@ -361,34 +373,30 @@ fn test_commit_builder_descendants(backend: TestRepoBackend) {
         .unwrap();
     let rebase_map = tx
         .repo_mut()
-        .rebase_descendants_with_options_return_map(&settings, Default::default())
+        .rebase_descendants_with_options_return_map(Default::default())
         .unwrap();
     assert_eq!(rebase_map.len(), 0);
 
     // Test with for_rewrite_from()
-    let mut tx = repo.start_transaction(&settings);
-    let commit4 = tx
-        .repo_mut()
-        .rewrite_commit(&settings, &commit2)
-        .write()
-        .unwrap();
+    let mut tx = repo.start_transaction();
+    let commit4 = tx.repo_mut().rewrite_commit(&commit2).write().unwrap();
     let rebase_map = tx
         .repo_mut()
-        .rebase_descendants_with_options_return_map(&settings, Default::default())
+        .rebase_descendants_with_options_return_map(Default::default())
         .unwrap();
     assert_rebased_onto(tx.repo_mut(), &rebase_map, &commit3, &[commit4.id()]);
     assert_eq!(rebase_map.len(), 1);
 
     // Test with for_rewrite_from() but new change id
-    let mut tx = repo.start_transaction(&settings);
+    let mut tx = repo.start_transaction();
     tx.repo_mut()
-        .rewrite_commit(&settings, &commit2)
+        .rewrite_commit(&commit2)
         .generate_new_change_id()
         .write()
         .unwrap();
     let rebase_map = tx
         .repo_mut()
-        .rebase_descendants_with_options_return_map(&settings, Default::default())
+        .rebase_descendants_with_options_return_map(Default::default())
         .unwrap();
     assert!(rebase_map.is_empty());
 }
