@@ -52,7 +52,6 @@ fn test_init_additional_workspace() {
     let ws2_root = test_workspace.root_dir().join("ws2_root");
     std::fs::create_dir(&ws2_root).unwrap();
     let (ws2, repo) = Workspace::init_workspace_with_existing_repo(
-        &settings,
         &ws2_root,
         test_workspace.repo_path(),
         &test_workspace.repo,
@@ -71,9 +70,12 @@ fn test_init_additional_workspace() {
     assert_eq!(ws2.workspace_id(), &ws2_id);
     assert_eq!(
         *ws2.repo_path(),
-        workspace.repo_path().canonicalize().unwrap()
+        dunce::canonicalize(workspace.repo_path()).unwrap()
+    );
+    assert_eq!(
+        *ws2.workspace_root(),
+        dunce::canonicalize(&ws2_root).unwrap()
     );
-    assert_eq!(*ws2.workspace_root(), ws2_root.canonicalize().unwrap());
     let same_workspace = Workspace::load(
         &settings,
         &ws2_root,
@@ -85,7 +87,7 @@ fn test_init_additional_workspace() {
     assert_eq!(same_workspace.workspace_id(), &ws2_id);
     assert_eq!(
         *same_workspace.repo_path(),
-        workspace.repo_path().canonicalize().unwrap()
+        dunce::canonicalize(workspace.repo_path()).unwrap()
     );
     assert_eq!(same_workspace.workspace_root(), ws2.workspace_root());
 }
