@@ -60,6 +60,7 @@ use jj_lib::tree::Tree;
 use jj_lib::tree_builder::TreeBuilder;
 use jj_lib::working_copy::SnapshotError;
 use jj_lib::working_copy::SnapshotOptions;
+use jj_lib::working_copy::SnapshotStats;
 use jj_lib::workspace::Workspace;
 use pollster::FutureExt;
 use tempfile::TempDir;
@@ -114,7 +115,7 @@ pub fn base_user_config() -> StackedConfig {
         operation.hostname = "host.example.com"
         debug.randomness-seed = 42
     "#;
-    let mut config = StackedConfig::empty();
+    let mut config = StackedConfig::with_defaults();
     config.add_layer(ConfigLayer::parse(ConfigSource::User, config_text).unwrap());
     config
 }
@@ -122,7 +123,7 @@ pub fn base_user_config() -> StackedConfig {
 /// Returns new immutable settings object that includes fake user configuration
 /// needed to run basic operations.
 pub fn user_settings() -> UserSettings {
-    UserSettings::from_config(base_user_config())
+    UserSettings::from_config(base_user_config()).unwrap()
 }
 
 #[derive(Debug)]
@@ -165,7 +166,7 @@ impl TestEnvironment {
     ) -> Arc<ReadonlyRepo> {
         RepoLoader::init_from_file_system(settings, repo_path, &self.default_store_factories())
             .unwrap()
-            .load_at_head(settings)
+            .load_at_head()
             .unwrap()
     }
 }
@@ -302,28 +303,29 @@ impl TestWorkspace {
     pub fn snapshot_with_options(
         &mut self,
         options: &SnapshotOptions,
-    ) -> Result<MergedTree, SnapshotError> {
+    ) -> Result<(MergedTree, SnapshotStats), SnapshotError> {
         let mut locked_ws = self.workspace.start_working_copy_mutation().unwrap();
-        let tree_id = locked_ws.locked_wc().snapshot(options)?;
+        let (tree_id, stats) = locked_ws.locked_wc().snapshot(options)?;
         // arbitrary operation id
         locked_ws.finish(self.repo.op_id().clone()).unwrap();
-        Ok(self.repo.store().get_root_tree(&tree_id).unwrap())
+        Ok((self.repo.store().get_root_tree(&tree_id).unwrap(), stats))
     }
 
     /// Like `snapshot_with_option()` but with default options
     pub fn snapshot(&mut self) -> Result<MergedTree, SnapshotError> {
-        self.snapshot_with_options(&SnapshotOptions::empty_for_test())
+        let (tree_id, _stats) = self.snapshot_with_options(&SnapshotOptions::empty_for_test())?;
+        Ok(tree_id)
     }
 }
 
-pub fn commit_transactions(settings: &UserSettings, txs: Vec<Transaction>) -> Arc<ReadonlyRepo> {
+pub fn commit_transactions(txs: Vec<Transaction>) -> Arc<ReadonlyRepo> {
     let repo_loader = txs[0].base_repo().loader().clone();
     let mut op_ids = vec![];
     for tx in txs {
         op_ids.push(tx.commit("test").unwrap().op_id().clone());
         std::thread::sleep(std::time::Duration::from_millis(1));
     }
-    let repo = repo_loader.load_at_head(settings).unwrap();
+    let repo = repo_loader.load_at_head().unwrap();
     // Test the setup. The assumption here is that the parent order matches the
     // order in which they were merged (which currently matches the transaction
     // commit order), so we want to know make sure they appear in a certain
@@ -404,18 +406,11 @@ pub fn create_random_tree(repo: &Arc<ReadonlyRepo>) -> MergedTreeId {
     create_tree(repo, &[(&path, "contents")]).id()
 }
 
-pub fn create_random_commit<'repo>(
-    mut_repo: &'repo mut MutableRepo,
-    settings: &UserSettings,
-) -> CommitBuilder<'repo> {
+pub fn create_random_commit(mut_repo: &mut MutableRepo) -> CommitBuilder<'_> {
     let tree_id = create_random_tree(mut_repo.base_repo());
     let number = rand::random::<u32>();
     mut_repo
-        .new_commit(
-            settings,
-            vec![mut_repo.store().root_commit_id().clone()],
-            tree_id,
-        )
+        .new_commit(vec![mut_repo.store().root_commit_id().clone()], tree_id)
         .set_description(format!("random commit {number}"))
 }
 
@@ -476,8 +471,8 @@ pub fn dump_tree(store: &Arc<Store>, tree_id: &MergedTreeId) -> String {
     buf
 }
 
-pub fn write_random_commit(mut_repo: &mut MutableRepo, settings: &UserSettings) -> Commit {
-    create_random_commit(mut_repo, settings).write().unwrap()
+pub fn write_random_commit(mut_repo: &mut MutableRepo) -> Commit {
+    create_random_commit(mut_repo).write().unwrap()
 }
 
 pub fn write_working_copy_file(workspace_root: &Path, path: &RepoPath, contents: &str) {
@@ -494,21 +489,17 @@ pub fn write_working_copy_file(workspace_root: &Path, path: &RepoPath, contents:
     file.write_all(contents.as_bytes()).unwrap();
 }
 
-pub struct CommitGraphBuilder<'settings, 'repo> {
-    settings: &'settings UserSettings,
+pub struct CommitGraphBuilder<'repo> {
     mut_repo: &'repo mut MutableRepo,
 }
 
-impl<'settings, 'repo> CommitGraphBuilder<'settings, 'repo> {
-    pub fn new(
-        settings: &'settings UserSettings,
-        mut_repo: &'repo mut MutableRepo,
-    ) -> CommitGraphBuilder<'settings, 'repo> {
-        CommitGraphBuilder { settings, mut_repo }
+impl<'repo> CommitGraphBuilder<'repo> {
+    pub fn new(mut_repo: &'repo mut MutableRepo) -> Self {
+        CommitGraphBuilder { mut_repo }
     }
 
     pub fn initial_commit(&mut self) -> Commit {
-        write_random_commit(self.mut_repo, self.settings)
+        write_random_commit(self.mut_repo)
     }
 
     pub fn commit_with_parents(&mut self, parents: &[&Commit]) -> Commit {
@@ -516,7 +507,7 @@ impl<'settings, 'repo> CommitGraphBuilder<'settings, 'repo> {
             .iter()
             .map(|commit| commit.id().clone())
             .collect_vec();
-        create_random_commit(self.mut_repo, self.settings)
+        create_random_commit(self.mut_repo)
             .set_parents(parent_ids)
             .write()
             .unwrap()
